@@ -110,13 +110,13 @@ class XMLToX(xmllib.XMLParser):
     def __init__(self):
         xmllib.XMLParser.__init__(self)
         self.translated=""
-        self.elements["FILE"]=(None,None)
-        self.elements["CHAP"]=(None,None)
-        self.elements["PART"]=(None,None)
-        self.elements["TEXT"]=(None,None)
-        self.elements["LIST"]=(None,None)
-        self.elements["ELEM"]=(None,None)
-        self.elements["CODE"]=(None,None)
+        self.elements["file"]=(None,None)
+        self.elements["chap"]=(None,None)
+        self.elements["part"]=(None,None)
+        self.elements["text"]=(None,None)
+        self.elements["list"]=(None,None)
+        self.elements["elem"]=(None,None)
+        self.elements["code"]=(None,None)
     def write(self,text):
         self.translated=self.translated+text
     def start_file(self,title):
@@ -148,34 +148,34 @@ class XMLToX(xmllib.XMLParser):
     def end_code(self):
         pass
     def unknown_starttag(self,tag,attributes):
-        if tag=="FILE":
-            self.start_file(attributes["TITLE"])
-        if tag=="CHAP":
-            self.start_chap(attributes["TITLE"])
-        if tag=="PART":
-            self.start_part(attributes["TITLE"])
-        if tag=="TEXT":
+        if tag=="file":
+            self.start_file(attributes["title"])
+        if tag=="chap":
+            self.start_chap(attributes["title"])
+        if tag=="part":
+            self.start_part(attributes["title"])
+        if tag=="text":
             self.start_text()
-        if tag=="LIST":
+        if tag=="list":
             self.start_list()
-        if tag=="ELEM":
+        if tag=="elem":
             self.start_elem()
-        if tag=="CODE":
+        if tag=="code":
             self.start_code()
     def unknown_endtag(self,tag):
-        if tag=="FILE":
+        if tag=="file":
             self.end_file()
-        elif tag=="CHAP":
+        elif tag=="chap":
             self.end_chap()
-        elif tag=="PART":
+        elif tag=="part":
             self.end_part()
-        elif tag=="TEXT":
+        elif tag=="text":
             self.end_text()
-        elif tag=="LIST":
+        elif tag=="list":
             self.end_list()
-        elif tag=="ELEM":
+        elif tag=="elem":
             self.end_elem()
-        elif tag=="CODE":
+        elif tag=="code":
             self.end_code()
     def translate(self,data,tag):
         return data
@@ -244,25 +244,25 @@ class XMLToPHP3(XMLToX):
         XMLToX.__init__(self)
     def start_file(self,title):
         self.write("\n\n<!-- www.ufoot.org : page begins here -->\n\n"+\
-                   "<CENTER>\n<H1>"+\
+                   "<center>\n<h1>"+\
                    title+\
-                   "</H1>\n</CENTER>\n")
+                   "</h1>\n</center>\n")
     def start_chap(self,title):
-        self.write("<HR>\n<H2>"+\
+        self.write("<hr />\n<h2>"+\
                    title+\
-                   "</H2>\n")
+                   "</h2>\n")
     def start_part(self,title):
-        self.write("<H3>"+\
+        self.write("<h3>"+\
                    title+\
-                   "</H3>\n")
+                   "</h3>\n")
     def start_text(self):
-        self.write("<P>")
+        self.write("<p>")
     def start_list(self):
-        self.write("<UL>")
+        self.write("<ul>")
     def start_elem(self):
-        self.write("<LI>")
+        self.write("<li>")
     def start_code(self):
-        self.write("<PRE>")
+        self.write("<pre>")
     def end_file(self):
         self.write("\n\n<!-- www.ufoot.org : page ends here -->\n\n")
     def end_chap(self):
@@ -270,13 +270,13 @@ class XMLToPHP3(XMLToX):
     def end_part(self):
         self.write("\n")
     def end_text(self):
-        self.write("</P>\n")
+        self.write("</p>\n")
     def end_list(self):
-        self.write("</UL>\n")
+        self.write("</ul>\n")
     def end_elem(self):
-        self.write("</LI>\n")
+        self.write("</li>\n")
     def end_code(self):
-        self.write("</PRE>\n")
+        self.write("</pre>\n")
     def translate(self,data,tag):
         result=data
         result=format_html(result)
@@ -287,15 +287,15 @@ class XMLToTeX(XMLToX):
         XMLToX.__init__(self)
     def start_file(self,title):
         self.write("\\chapter{"+\
-                   self.translate(title,"TEXT")+\
+                   self.translate(title,"text")+\
                    "}\n")
     def start_chap(self,title):
         self.write("\\section{"+\
-                   self.translate(title,"TEXT")+\
+                   self.translate(title,"text")+\
                    "}\n")
     def start_part(self,title):
         self.write("\\subsection{"+\
-                   self.translate(title,"TEXT")+\
+                   self.translate(title,"text")+\
                    "}\n")
     def start_text(self):
         self.write("\n")
@@ -322,7 +322,7 @@ class XMLToTeX(XMLToX):
     def translate(self,data,tag):
         result=data
 	result=format_email_and_url(result)
-        if (tag!="CODE"):
+        if (tag!="code"):
             result=format_tex(result)
         return result
 
@@ -364,7 +364,7 @@ class XMLToMan(XMLToX):
         result=string.replace(result,"\\","\\\\")
         result=string.replace(result,".","\.")
         result=string.replace(result,"-","\-")
-        if (tag=="CODE"):
+        if (tag=="code"):
             result=string.replace(result,"\n","\n.br\n")
         else:
             result=remove_duplicate_blanks(result)
@@ -416,12 +416,12 @@ class XMLToTxt(XMLToX):
     def translate(self,data,tag):
         result=data
 	result=format_email_and_url(result)
-        if (tag=="CODE"):
+        if (tag=="code"):
             result=" "*self.indent+\
                     string.replace(result,"\n","\n"+" "*self.indent)
         else:
             result=format_text(result,self.indent,80)
-            if (tag=="ELEM"):
+            if (tag=="elem"):
                 result=" "*(self.indent-2)+"* "+result[self.indent:]
         return result
 
@@ -462,7 +462,7 @@ class XMLToTexi(XMLToX):
         result=data
 	result=format_email_and_url(result)
 
-        if (tag!="CODE"):
+        if (tag!="code"):
             result=remove_duplicate_blanks(result)
         result=format_texi(result)
         return result
