@@ -28,6 +28,10 @@ proc_fix_unix()
 proc_fix_dos()
 {
    proc_filelist
+   FILELIST="$FILELIST `find . -type f "(" \
+   	-name "*.bat" -o \
+        -name "*.js" \
+	")"`" 
    proc_utod
 }
 
@@ -51,7 +55,8 @@ proc_filelist()
       -name "COPYING" -o \
       -name "INSTALL" -o \
       -name "README" -o \
-      -name "TOTO" -o \
+      -name "README.fr" -o \
+      -name "README.de" -o \
       -name "ChangeLog" \
    ")"`
 }
