@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -68,33 +68,33 @@ typedef struct
    * will be put into the map. this  
    * value decreases at each round.  
    */
-  int     val;
+  int val;
   /* x position of the cursor         */
-  int     x;
+  int x;
   /* y position of the cursor         */
-  int     y;           
+  int y;
   /* 
    * true if the player who owns this 
    * cursor is playing with it        
    */
-  int     active; 
+  int active;
   /* team the cursor belongs to       */
-  int     team; 
+  int team;
   /* 
    * time at which this cursor has    
    * lost. it seems that the diff     
    * between cursor and team is not   
    * well defined 8-(                 
    */
-  int     loose_time; 
+  int loose_time;
   /* wether you are 1st or 2nd...     */
-  int     score_order;
+  int score_order;
   /* 
    * first color used by this cursor  
    * in the 256 color palette. again  
    * a cursor is associated to a team 
    */
-  int     color_entry;
+  int color_entry;
   /* 
    *      this value holds the state of all
    * the keys associated to the cursor
@@ -105,25 +105,26 @@ typedef struct
    * - CURSOR_KEY_LEFT  
    * which are defined in move.h      
    */
-  int     key_state;  
+  int key_state;
   /* true if the player is a computer */
-  int     control_type;
+  int control_type;
   /* 
    * true if the player is located on 
    * a remote machine                 
    */
-  int     from_network;
+  int from_network;
   /*
    * the name of the player
    */
-  char name[NAME_SIZE+1];
-} CURSOR;
+  char name[NAME_SIZE + 1];
+}
+CURSOR;
 
 /*==================================================================*/
 /* variables globales                                               */
 /*==================================================================*/
 
-extern CURSOR CURRENT_CURSOR [NB_TEAMS];
+extern CURSOR CURRENT_CURSOR[NB_TEAMS];
 
 /*==================================================================*/
 /* fonctions globales                                               */
