@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -63,6 +63,7 @@
 #include "palette.h"
 #include "startup.h"
 #include "texture.h"
+#include "macro.h"
 
 /*==================================================================*/
 /* defines                                                          */
@@ -74,60 +75,64 @@
 /* variables globales                                               */
 /*==================================================================*/
 
-int SAMPLE_WATER_NUMBER=0;
-int RAW_TEXTURE_NUMBER=0;
-int RAW_MAP_NUMBER=0;
-int MIDI_MUSIC_NUMBER=0;
+int SAMPLE_WATER_NUMBER = 0;
+int RAW_TEXTURE_NUMBER = 0;
+int RAW_MAP_NUMBER = 0;
+int MIDI_MUSIC_NUMBER = 0;
 
-int LOADED_BACK=0;
-int LOADED_TEXTURE=0;
-int LOADED_SFX=0;
-int LOADED_WATER=0;
-int LOADED_MUSIC=0;
+int LOADED_BACK = 0;
+int LOADED_TEXTURE = 0;
+int LOADED_SFX = 0;
+int LOADED_WATER = 0;
+int LOADED_MUSIC = 0;
 
-SAMPLE *SAMPLE_SFX_TIME=NULL;
-SAMPLE *SAMPLE_SFX_WIN=NULL;
-SAMPLE *SAMPLE_SFX_GO=NULL;
-SAMPLE *SAMPLE_SFX_CLICK=NULL;
-SAMPLE *SAMPLE_SFX_LOOSE=NULL;
-SAMPLE *SAMPLE_SFX_CONNECT=NULL;
+SAMPLE *SAMPLE_SFX_TIME = NULL;
+SAMPLE *SAMPLE_SFX_WIN = NULL;
+SAMPLE *SAMPLE_SFX_GO = NULL;
+SAMPLE *SAMPLE_SFX_CLICK = NULL;
+SAMPLE *SAMPLE_SFX_LOOSE = NULL;
+SAMPLE *SAMPLE_SFX_CONNECT = NULL;
 
 SAMPLE *SAMPLE_WATER[SAMPLE_WATER_MAX_NUMBER];
-void   *RAW_MAP[RAW_MAP_MAX_NUMBER];
-void   *RAW_MAP_ORDERED[RAW_MAP_MAX_NUMBER];
-void   *RAW_TEXTURE[RAW_TEXTURE_MAX_NUMBER];
-MIDI   *MIDI_MUSIC[MIDI_MUSIC_MAX_NUMBER];
+void *RAW_MAP[RAW_MAP_MAX_NUMBER];
+void *RAW_MAP_ORDERED[RAW_MAP_MAX_NUMBER];
+void *RAW_TEXTURE[RAW_TEXTURE_MAX_NUMBER];
+MIDI *MIDI_MUSIC[MIDI_MUSIC_MAX_NUMBER];
 
-BITMAP *BACK_IMAGE=NULL;
+BITMAP *BACK_IMAGE = NULL;
 
-FONT *BIG_FONT=NULL;
-FONT *SMALL_FONT=NULL;
-BITMAP *BIG_MOUSE_CURSOR=NULL;
-BITMAP *SMALL_MOUSE_CURSOR=NULL;
-BITMAP *INVISIBLE_MOUSE_CURSOR=NULL;
+FONT *BIG_FONT = NULL;
+FONT *SMALL_FONT = NULL;
+BITMAP *BIG_MOUSE_CURSOR = NULL;
+BITMAP *SMALL_MOUSE_CURSOR = NULL;
+BITMAP *INVISIBLE_MOUSE_CURSOR = NULL;
 
-static RGB *FONT_PALETTE=NULL;
-static RGB *BACK_PALETTE=NULL;
+static RGB *FONT_PALETTE = NULL;
+static RGB *BACK_PALETTE = NULL;
 
-static int CUSTOM_TEXTURE_OK=0;
-static int CUSTOM_MAP_OK=0;
-static int CUSTOM_MUSIC_OK=0;
+static int CUSTOM_TEXTURE_OK = 0;
+static int CUSTOM_MAP_OK = 0;
+static int CUSTOM_MUSIC_OK = 0;
 
 /*------------------------------------------------------------------*/
 /* chargement des effets sonores                                    */
 /*------------------------------------------------------------------*/
 
 /*------------------------------------------------------------------*/
-static void lock_sound (SAMPLE *smp)
+static void
+lock_sound (SAMPLE * smp)
 {
   LOCK_VARIABLE (*smp);
 #ifdef ALLEGRO_DOS
-  _go32_dpmi_lock_data (smp->data,(smp->bits/8)*smp->len);
+  _go32_dpmi_lock_data (smp->data, (smp->bits / 8) * smp->len);
+#else
+  LW_MACRO_NOP (smp);
 #endif
 }
 
 /*------------------------------------------------------------------*/
-static void read_sfx_dat (DATAFILE *df)
+static void
+read_sfx_dat (DATAFILE * df)
 {
   SAMPLE *list[SAMPLE_SFX_NUMBER];
   int i;
@@ -137,37 +142,38 @@ static void read_sfx_dat (DATAFILE *df)
    * to all sounds. This will operate as default value which
    * will prevent the game from segfaulting if we use it with
    * an outdated or too recent datafile
-   */ 
-  for (i=0;i<SAMPLE_SFX_NUMBER && df[i].type!=DAT_END;++i)
+   */
+  for (i = 0; i < SAMPLE_SFX_NUMBER && df[i].type != DAT_END; ++i)
     {
-      list[i]=df[0].dat;
+      list[i] = df[0].dat;
     }
 
   /*
    * Now we associate the real sounds, provided that they exist...
    */
-  for (i=0;i<6 && df[i].type!=DAT_END;++i)
+  for (i = 0; i < 6 && df[i].type != DAT_END; ++i)
     {
-      list[i]=df[i].dat;
-      lock_sound(list[i]);
+      list[i] = df[i].dat;
+      lock_sound (list[i]);
     }
 
-  SAMPLE_SFX_TIME=list[0];
-  SAMPLE_SFX_WIN=list[1];
-  SAMPLE_SFX_CONNECT=list[2];
-  SAMPLE_SFX_GO=list[3];
-  SAMPLE_SFX_CLICK=list[4];
-  SAMPLE_SFX_LOOSE=list[5];
+  SAMPLE_SFX_TIME = list[0];
+  SAMPLE_SFX_WIN = list[1];
+  SAMPLE_SFX_CONNECT = list[2];
+  SAMPLE_SFX_GO = list[3];
+  SAMPLE_SFX_CLICK = list[4];
+  SAMPLE_SFX_LOOSE = list[5];
 }
 
 /*------------------------------------------------------------------*/
-static void read_water_dat (DATAFILE *df)
+static void
+read_water_dat (DATAFILE * df)
 {
   int i;
 
-  for (i=0; i<SAMPLE_WATER_DAT_NUMBER && df[i].type!=DAT_END; ++i)
+  for (i = 0; i < SAMPLE_WATER_DAT_NUMBER && df[i].type != DAT_END; ++i)
     {
-      SAMPLE_WATER[i]=df[i].dat;
+      SAMPLE_WATER[i] = df[i].dat;
       lock_sound (SAMPLE_WATER[i]);
       SAMPLE_WATER_NUMBER++;
     }
@@ -178,38 +184,41 @@ static void read_water_dat (DATAFILE *df)
 /*------------------------------------------------------------------*/
 
 /*------------------------------------------------------------------*/
-static void read_texture_dat (DATAFILE *df)
+static void
+read_texture_dat (DATAFILE * df)
 {
   int i;
 
-  RAW_TEXTURE_NUMBER=0;
-  for (i=0; i<RAW_TEXTURE_DAT_NUMBER && df[i].type!=DAT_END; ++i)
+  RAW_TEXTURE_NUMBER = 0;
+  for (i = 0; i < RAW_TEXTURE_DAT_NUMBER && df[i].type != DAT_END; ++i)
     {
-      RAW_TEXTURE[i]=df[i].dat;
+      RAW_TEXTURE[i] = df[i].dat;
       RAW_TEXTURE_NUMBER++;
     }
 }
 
 /*------------------------------------------------------------------*/
-static void read_map_dat (DATAFILE *df)
+static void
+read_map_dat (DATAFILE * df)
 {
   int i;
 
-  RAW_MAP_NUMBER=0;
-  for (i=0; i<RAW_MAP_DAT_NUMBER && df[i].type!=DAT_END; ++i)
+  RAW_MAP_NUMBER = 0;
+  for (i = 0; i < RAW_MAP_DAT_NUMBER && df[i].type != DAT_END; ++i)
     {
-      RAW_MAP[i]=df[i].dat;
+      RAW_MAP[i] = df[i].dat;
       RAW_MAP_NUMBER++;
     }
 }
 
 /*------------------------------------------------------------------*/
-static void read_back_dat (DATAFILE *df)
+static void
+read_back_dat (DATAFILE * df)
 {
-  int i,x,y;
+  int i, x, y;
 
-  BACK_PALETTE=df[1].dat;
-  BACK_IMAGE=df[0].dat;
+  BACK_PALETTE = df[1].dat;
+  BACK_IMAGE = df[0].dat;
 
   /*
    * strange, with Allegro 4.0, the liquidwarcol utility
@@ -218,330 +227,344 @@ static void read_back_dat (DATAFILE *df)
    * start at color 0, which explains the "18 shift"
    */
 
-  for (i=0; i<=45; ++i)
-    GLOBAL_PALETTE[i+18]=BACK_PALETTE[i];
+  for (i = 0; i <= 45; ++i)
+    GLOBAL_PALETTE[i + 18] = BACK_PALETTE[i];
 
-  for (x=0;x<BACK_IMAGE->w;++x)
-    for (y=0;y<BACK_IMAGE->w;++y)
+  for (x = 0; x < BACK_IMAGE->w; ++x)
+    for (y = 0; y < BACK_IMAGE->w; ++y)
       {
-	putpixel(BACK_IMAGE,x,y,getpixel(BACK_IMAGE,x,y)+18);
+	putpixel (BACK_IMAGE, x, y, getpixel (BACK_IMAGE, x, y) + 18);
       }
 }
 
 /*------------------------------------------------------------------*/
-static void create_default_back(void)
+static void
+create_default_back (void)
 {
-  static RGB back_coul={1,1,8};
+  static RGB back_coul;
 
-  BACK_IMAGE=my_create_bitmap (1,1);
-  putpixel (BACK_IMAGE,0,0,18);
-  GLOBAL_PALETTE[18]=back_coul;
+  memset (&back_coul, 0, sizeof (RGB));
+  back_coul.r = 1;
+  back_coul.g = 1;
+  back_coul.b = 8;
+
+  BACK_IMAGE = my_create_bitmap (1, 1);
+  putpixel (BACK_IMAGE, 0, 0, 18);
+  GLOBAL_PALETTE[18] = back_coul;
 }
 
 /*------------------------------------------------------------------*/
-static void read_font_dat (DATAFILE *df)
+static void
+read_font_dat (DATAFILE * df)
 {
   int i;
 
-  FONT_PALETTE=df[4].dat;
-  SMALL_FONT=df[0].dat;
-  BIG_FONT=df[1].dat;
-  SMALL_MOUSE_CURSOR=df[2].dat;
-  BIG_MOUSE_CURSOR=df[3].dat;
-  INVISIBLE_MOUSE_CURSOR=df[5].dat;
+  FONT_PALETTE = df[4].dat;
+  SMALL_FONT = df[0].dat;
+  BIG_FONT = df[1].dat;
+  SMALL_MOUSE_CURSOR = df[2].dat;
+  BIG_MOUSE_CURSOR = df[3].dat;
+  INVISIBLE_MOUSE_CURSOR = df[5].dat;
 
-  for (i=1; i<=17; ++i)
-    GLOBAL_PALETTE[i]=FONT_PALETTE[i];
+  for (i = 1; i <= 17; ++i)
+    GLOBAL_PALETTE[i] = FONT_PALETTE[i];
 }
 
 /*------------------------------------------------------------------*/
-static void read_music_dat (DATAFILE *df)
+static void
+read_music_dat (DATAFILE * df)
 {
   int i;
 
-  MIDI_MUSIC_NUMBER=0;
-  for (i=0; i<MIDI_MUSIC_DAT_NUMBER && df[i].type!=DAT_END; ++i)
+  MIDI_MUSIC_NUMBER = 0;
+  for (i = 0; i < MIDI_MUSIC_DAT_NUMBER && df[i].type != DAT_END; ++i)
     {
-      MIDI_MUSIC[i]=df[i].dat;
+      MIDI_MUSIC[i] = df[i].dat;
       MIDI_MUSIC_NUMBER++;
     }
 }
 
 /*------------------------------------------------------------------*/
-int load_dat (void)
+int
+load_dat (void)
 {
-  int result=1;
+  int result = 1;
   int loadable;
   DATAFILE *df;
 
-  log_print_str("Loading data from \"");
-  log_print_str(STARTUP_DAT_PATH);
-  log_print_str("\"");
+  log_print_str ("Loading data from \"");
+  log_print_str (STARTUP_DAT_PATH);
+  log_print_str ("\"");
 
 #ifdef ALLEGRO_DOS
-  loadable=1;  
+  loadable = 1;
 #else
-  loadable=exists(STARTUP_DAT_PATH);
+  loadable = exists (STARTUP_DAT_PATH);
 #endif
 
-  display_success(loadable);
+  display_success (loadable);
 
   if (loadable)
     {
-      log_print_str( "Loading fonts");
-      log_flush();
-      df=load_datafile_object (STARTUP_DAT_PATH,"font_dat");
-      if (result&=(df!=NULL))
-        read_font_dat (df[0].dat);
-      display_success (df!=NULL);
+      log_print_str ("Loading fonts");
+      log_flush ();
+      df = load_datafile_object (STARTUP_DAT_PATH, "font_dat");
+      if (result &= (df != NULL))
+	read_font_dat (df[0].dat);
+      display_success (df != NULL);
     }
   if (loadable)
     {
-      log_print_str( "Loading maps");
-      log_flush();
-      df=load_datafile_object (STARTUP_DAT_PATH,"map_dat");
-      if (result&=(df!=NULL))
-        read_map_dat (df[0].dat);
-      display_success (df!=NULL);
+      log_print_str ("Loading maps");
+      log_flush ();
+      df = load_datafile_object (STARTUP_DAT_PATH, "map_dat");
+      if (result &= (df != NULL))
+	read_map_dat (df[0].dat);
+      display_success (df != NULL);
     }
 
   if (loadable && STARTUP_BACK_STATE)
     {
-      log_print_str( "Loading background bitmap");
+      log_print_str ("Loading background bitmap");
       log_flush ();
-      df=load_datafile_object (STARTUP_DAT_PATH,"back_dat");
-      if (df!=NULL)
+      df = load_datafile_object (STARTUP_DAT_PATH, "back_dat");
+      if (df != NULL)
 	{
 	  read_back_dat (df[0].dat);
-	  LOADED_BACK=1;
+	  LOADED_BACK = 1;
 	}
       else
-        {
+	{
 	  create_default_back ();
-	  result&=!STARTUP_CHECK;
-        }
-      display_success (df!=NULL);
+	  result &= !STARTUP_CHECK;
+	}
+      display_success (df != NULL);
     }
   else
     create_default_back ();
   if (loadable && STARTUP_SFX_STATE)
     {
-      log_print_str( "Loading sound fx");
-      log_flush();
-      df=load_datafile_object (STARTUP_DAT_PATH,"sfx_dat");
-      if (df!=NULL)
+      log_print_str ("Loading sound fx");
+      log_flush ();
+      df = load_datafile_object (STARTUP_DAT_PATH, "sfx_dat");
+      if (df != NULL)
 	{
 	  read_sfx_dat (df[0].dat);
-	  LOADED_SFX=1;
+	  LOADED_SFX = 1;
 	}
       else
-	result&=!STARTUP_CHECK;
-      display_success (df!=NULL);
+	result &= !STARTUP_CHECK;
+      display_success (df != NULL);
     }
-  if (loadable && STARTUP_TEXTURE_STATE)    {
-      log_print_str( "Loading textures");
-      log_flush();
-      df=load_datafile_object (STARTUP_DAT_PATH,"texture_dat");
-      if (df!=NULL)
+  if (loadable && STARTUP_TEXTURE_STATE)
+    {
+      log_print_str ("Loading textures");
+      log_flush ();
+      df = load_datafile_object (STARTUP_DAT_PATH, "texture_dat");
+      if (df != NULL)
 	{
 	  read_texture_dat (df[0].dat);
-	  LOADED_TEXTURE=1;
+	  LOADED_TEXTURE = 1;
 	}
       else
-	result&=!STARTUP_CHECK;
-      display_success (df!=NULL);
+	result &= !STARTUP_CHECK;
+      display_success (df != NULL);
     }
 
   if (loadable && STARTUP_WATER_STATE)
     {
-      log_print_str( "Loading water sounds");
+      log_print_str ("Loading water sounds");
       log_flush ();
-      df=load_datafile_object (STARTUP_DAT_PATH,"water_dat");
-      if (df!=NULL)
+      df = load_datafile_object (STARTUP_DAT_PATH, "water_dat");
+      if (df != NULL)
 	{
 	  read_water_dat (df[0].dat);
-	  LOADED_WATER=1;
+	  LOADED_WATER = 1;
 	}
       else
-	result&=!STARTUP_CHECK;
-      display_success (df!=NULL);
+	result &= !STARTUP_CHECK;
+      display_success (df != NULL);
     }
 
   if (loadable && STARTUP_MUSIC_STATE)
     {
-      log_print_str( "Loading midi music");
+      log_print_str ("Loading midi music");
       log_flush ();
-      df=load_datafile_object (STARTUP_DAT_PATH,"music_dat");
-      if (df!=NULL)
+      df = load_datafile_object (STARTUP_DAT_PATH, "music_dat");
+      if (df != NULL)
 	{
 	  read_music_dat (df[0].dat);
-	  LOADED_MUSIC=1;
+	  LOADED_MUSIC = 1;
 	}
       else
-	result&=!STARTUP_CHECK;
-      display_success (df!=NULL);
+	result &= !STARTUP_CHECK;
+      display_success (df != NULL);
     }
 
   return loadable && result;
 }
 
 /*------------------------------------------------------------------*/
-static void load_custom_texture_callback(const char *file, int mode, int unused)
+static void
+load_custom_texture_callback (const char *file, int mode, int unused)
 {
   void *pointeur;
 
-  if ((pointeur=archive_raw_texture(file)) !=NULL)
+  LW_MACRO_NOP (mode);
+  LW_MACRO_NOP (unused);
+
+  if ((pointeur = lw_texture_archive_raw (file)) != NULL)
     {
-      RAW_TEXTURE[RAW_TEXTURE_NUMBER++]=pointeur;
-      log_print_str("+");
-      CUSTOM_TEXTURE_OK=1;
+      RAW_TEXTURE[RAW_TEXTURE_NUMBER++] = pointeur;
+      log_print_str ("+");
+      CUSTOM_TEXTURE_OK = 1;
     }
   else
     {
-      log_print_str("-");
+      log_print_str ("-");
     }
-  log_flush();
+  log_flush ();
 }
 
 /*------------------------------------------------------------------*/
-static int load_custom_texture (void)
+static int
+load_custom_texture (void)
 {
-  int result=1;
+  int result = 1;
   char buf[512];
-  int l;
 
-  strcpy(buf,STARTUP_TEX_PATH);
-  l=strlen(buf);
+  LW_MACRO_SPRINTF1 (buf, "%s\\*.*", STARTUP_TEX_PATH);
 
-  strcpy(buf+l,"\\*.*");
+  fix_filename_case (buf);
+  fix_filename_slashes (buf);
 
-  fix_filename_case(buf);
-  fix_filename_slashes(buf);
-
-  CUSTOM_TEXTURE_OK=0;
-  for_each_file(buf,FA_RDONLY|FA_ARCH,load_custom_texture_callback,0);
-  result=CUSTOM_TEXTURE_OK;
+  CUSTOM_TEXTURE_OK = 0;
+  for_each_file (buf, FA_RDONLY | FA_ARCH, load_custom_texture_callback, 0);
+  result = CUSTOM_TEXTURE_OK;
 
   return result;
 }
 
 /*------------------------------------------------------------------*/
-static void load_custom_map_callback(const char *file, int mode, int unused)
+static void
+load_custom_map_callback (const char *file, int mode, int unused)
 {
   void *pointeur;
 
-  if ((pointeur=archive_raw_map(file)) !=NULL)
+  LW_MACRO_NOP (mode);
+  LW_MACRO_NOP (unused);
+
+  if ((pointeur = lw_map_archive_raw (file)) != NULL)
     {
-      RAW_MAP[RAW_MAP_NUMBER++]=pointeur;
-      log_print_str("+");
-      CUSTOM_MAP_OK=1;
+      RAW_MAP[RAW_MAP_NUMBER++] = pointeur;
+      log_print_str ("+");
+      CUSTOM_MAP_OK = 1;
     }
   else
     {
-      log_print_str("-");
+      log_print_str ("-");
     }
 }
 
 /*------------------------------------------------------------------*/
-static int load_custom_map (void)
+static int
+load_custom_map (void)
 {
-  int result=1;
+  int result = 1;
   char buf[512];
-  int l;
 
-  strcpy(buf,STARTUP_MAP_PATH);
-  l=strlen(buf);
+  LW_MACRO_SPRINTF1 (buf, "%s\\*.*", STARTUP_MAP_PATH);
 
-  strcpy(buf+l,"\\*.*");
+  fix_filename_case (buf);
+  fix_filename_slashes (buf);
 
-  fix_filename_case(buf);
-  fix_filename_slashes(buf);
-
-  CUSTOM_MAP_OK=0;
-  for_each_file(buf,FA_RDONLY|FA_ARCH,load_custom_map_callback,0);
-  result=CUSTOM_MAP_OK;  
+  CUSTOM_MAP_OK = 0;
+  for_each_file (buf, FA_RDONLY | FA_ARCH, load_custom_map_callback, 0);
+  result = CUSTOM_MAP_OK;
 
   return result;
 }
 
 /*------------------------------------------------------------------*/
-static void load_custom_music_callback(const char *file, int mode, int unused)
+static void
+load_custom_music_callback (const char *file, int mode, int unused)
 {
   void *pointeur;
 
-  if ((pointeur=load_midi(file)) !=NULL)
+  LW_MACRO_NOP (mode);
+  LW_MACRO_NOP (unused);
+
+  if ((pointeur = load_midi (file)) != NULL)
     {
-      MIDI_MUSIC[MIDI_MUSIC_NUMBER++]=pointeur;
-      log_print_str("+");
-      CUSTOM_MUSIC_OK=1;
+      MIDI_MUSIC[MIDI_MUSIC_NUMBER++] = pointeur;
+      log_print_str ("+");
+      CUSTOM_MUSIC_OK = 1;
     }
   else
     {
-      log_print_str("-");
+      log_print_str ("-");
     }
-  log_flush();
+  log_flush ();
 }
 
 /*------------------------------------------------------------------*/
-static int load_custom_music (void)
+static int
+load_custom_music (void)
 {
-  int result=1;
+  int result = 1;
   char buf[512];
-  int l;
 
-  strcpy(buf,STARTUP_MID_PATH);
-  l=strlen(buf);
+  LW_MACRO_SPRINTF1 (buf, "%s\\*.*", STARTUP_MID_PATH);
 
-  strcpy(buf+l,"\\*.*");
+  fix_filename_case (buf);
+  fix_filename_slashes (buf);
 
-  fix_filename_case(buf);
-  fix_filename_slashes(buf);
-
-  CUSTOM_MUSIC_OK=0;
-  for_each_file(buf,FA_RDONLY|FA_ARCH,load_custom_music_callback,0);
-  result=CUSTOM_MUSIC_OK;
+  CUSTOM_MUSIC_OK = 0;
+  for_each_file (buf, FA_RDONLY | FA_ARCH, load_custom_music_callback, 0);
+  result = CUSTOM_MUSIC_OK;
 
   return result;
 }
 
 /*------------------------------------------------------------------*/
-int load_custom (void)
+int
+load_custom (void)
 {
-  int success,result=1;
+  int success, result = 1;
 
   if (STARTUP_TEXTURE_STATE && STARTUP_CUSTOM_STATE)
     {
-      log_print_str( "Loading custom textures from \"");
-      log_print_str(STARTUP_TEX_PATH);
-      log_print_str("\" ");
-      log_flush();
-      success=load_custom_texture ();
+      log_print_str ("Loading custom textures from \"");
+      log_print_str (STARTUP_TEX_PATH);
+      log_print_str ("\" ");
+      log_flush ();
+      success = load_custom_texture ();
       if (!success)
-	result&=!STARTUP_CHECK;
+	result &= !STARTUP_CHECK;
       display_success (success);
     }
 
   if (STARTUP_CUSTOM_STATE)
     {
-      log_print_str( "Loading custom maps from \"");
-      log_print_str(STARTUP_MAP_PATH);
-      log_print_str("\" ");
-      log_flush();
-      success=load_custom_map();
+      log_print_str ("Loading custom maps from \"");
+      log_print_str (STARTUP_MAP_PATH);
+      log_print_str ("\" ");
+      log_flush ();
+      success = load_custom_map ();
       if (!success)
-	result&=!STARTUP_CHECK;
+	result &= !STARTUP_CHECK;
       display_success (success);
     }
 
   if (STARTUP_CUSTOM_STATE && STARTUP_MUSIC_STATE)
     {
-      log_print_str( "Loading custom musics from \"");
-      log_print_str(STARTUP_MID_PATH);
-      log_print_str("\" ");
-      log_flush();
-      success=load_custom_music();
+      log_print_str ("Loading custom musics from \"");
+      log_print_str (STARTUP_MID_PATH);
+      log_print_str ("\" ");
+      log_flush ();
+      success = load_custom_music ();
       if (!success)
-	result&=!STARTUP_CHECK;
+	result &= !STARTUP_CHECK;
       display_success (success);
     }
 
@@ -549,38 +572,38 @@ int load_custom (void)
 }
 
 /*------------------------------------------------------------------*/
-void order_map (void)
+void
+order_map (void)
 {
-  int incorrect_order=1;
+  int incorrect_order = 1;
   int i;
 
 
-  char name1[LW_MAP_READABLE_NAME_SIZE+1];
-  char name2[LW_MAP_READABLE_NAME_SIZE+1];
+  char name1[LW_MAP_READABLE_NAME_SIZE + 1];
+  char name2[LW_MAP_READABLE_NAME_SIZE + 1];
   void *temp;
 
-  for (i=0;i<RAW_MAP_NUMBER;++i)
+  for (i = 0; i < RAW_MAP_NUMBER; ++i)
     {
-      RAW_MAP_ORDERED[i]=RAW_MAP[i];
+      RAW_MAP_ORDERED[i] = RAW_MAP[i];
     }
 
   while (incorrect_order)
     {
-      incorrect_order=0;
+      incorrect_order = 0;
 
-      for (i=0;i<RAW_MAP_NUMBER-1;++i)
+      for (i = 0; i < RAW_MAP_NUMBER - 1; ++i)
 	{
-	  strcpy(name1,get_map_readable_name(i,0));
-	  strcpy(name2,get_map_readable_name(i+1,0));
-	  if (strcmp(name1,name2)>0)
+	  LW_MACRO_STRCPY (name1, lw_map_get_readable_name (i, 0));
+	  LW_MACRO_STRCPY (name2, lw_map_get_readable_name (i + 1, 0));
+	  if (strcmp (name1, name2) > 0)
 	    {
-	      incorrect_order=1;
+	      incorrect_order = 1;
 
-	      temp=RAW_MAP_ORDERED[i];
-	      RAW_MAP_ORDERED[i]=RAW_MAP_ORDERED[i+1];
-	      RAW_MAP_ORDERED[i+1]=temp;
+	      temp = RAW_MAP_ORDERED[i];
+	      RAW_MAP_ORDERED[i] = RAW_MAP_ORDERED[i + 1];
+	      RAW_MAP_ORDERED[i + 1] = temp;
 	    }
 	}
     }
 }
-
