@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -69,133 +69,142 @@
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-static int return_d_close(void)
+static int
+return_d_close (void)
 {
   return (D_CLOSE);
 }
 
 /*------------------------------------------------------------------*/
-static int standard_error (char *str)
+static int
+standard_error (char *str)
 {
   DIALOG d[3];
 
-  memset(d,0,sizeof(d));
+  memset (d, 0, sizeof (d));
 
   color_one_dialog (d);
-  d[0].proc=my_textbox_proc;
-  d[0].d2=0;
-  d[0].dp=str;
-  d[0].key=0;
-  d[0].flags=0;
-  d[0].x=MENU_VIRTUAL_W/4;
-  d[0].y=(3*MENU_VIRTUAL_H)/8;
-  d[0].w=(MENU_VIRTUAL_W)/2;
-  d[0].h=(MENU_VIRTUAL_H)/4;
+  d[0].proc = my_textbox_proc;
+  d[0].d2 = 0;
+  d[0].dp = str;
+  d[0].key = 0;
+  d[0].flags = 0;
+  d[0].x = MENU_VIRTUAL_W / 4;
+  d[0].y = (3 * MENU_VIRTUAL_H) / 8;
+  d[0].w = (MENU_VIRTUAL_W) / 2;
+  d[0].h = (MENU_VIRTUAL_H) / 4;
   menu_real_coord (d);
 
-  d[1].proc=d_keyboard_proc;
-  d[1].dp=return_d_close;
-  d[1].key=' ';
-  d[1].d1=KEY_ENTER;
-  d[1].d2=KEY_ESC;
+  d[1].proc = d_keyboard_proc;
+  d[1].dp = return_d_close;
+  d[1].key = ' ';
+  d[1].d1 = KEY_ENTER;
+  d[1].d2 = KEY_ESC;
 
-  d[2].proc=NULL;
+  d[2].proc = NULL;
+
+  my_do_dialog (d, 0);
 
-  my_do_dialog(d,0);
- 
   return 0;
 }
 
 /*------------------------------------------------------------------*/
-int error_not_enough_teams (void)
+int
+error_not_enough_teams (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_NOTENOUGHTEAMS)));
+  return (standard_error (lw_lang_string
+			  (LW_LANG_STRING_ERROR_NOTENOUGHTEAMS)));
 }
 
 /*------------------------------------------------------------------*/
-int error_not_enough_big_data (void)
+int
+error_not_enough_big_data (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_NOTENOUGHBIGDATA)));
+  return (standard_error (lw_lang_string
+			  (LW_LANG_STRING_ERROR_NOTENOUGHBIGDATA)));
 }
 
 /*------------------------------------------------------------------*/
-int error_graphics_init_failed (void)
+int
+error_graphics_init_failed (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_GRAPHICSINITFAILED)));
+  return (standard_error (lw_lang_string
+			  (LW_LANG_STRING_ERROR_GRAPHICSINITFAILED)));
 }
 
 /*------------------------------------------------------------------*/
-int error_no_network_support (void)
+int
+error_no_network_support (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_NONETWORKSUPPORT)));
+  return (standard_error (lw_lang_string
+			  (LW_LANG_STRING_ERROR_NONETWORKSUPPORT)));
 }
 
 /*------------------------------------------------------------------*/
-int error_unable_to_connect(void)
+int
+error_unable_to_connect (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_UNABLETOCONNECT)));
+  return (standard_error (lw_lang_string
+			  (LW_LANG_STRING_ERROR_UNABLETOCONNECT)));
 }
 
 /*------------------------------------------------------------------*/
-int error_not_a_liquidwar_server(void)
+int
+error_not_a_liquidwar_server (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_NOTALIQUIDWARSERVER)));
+  return (standard_error (lw_lang_string
+			  (LW_LANG_STRING_ERROR_NOTALIQUIDWARSERVER)));
 }
 
 /*------------------------------------------------------------------*/
-int error_wrong_version(void)
+int
+error_wrong_version (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_WRONGVERSION)));
+  return (standard_error (lw_lang_string
+			  (LW_LANG_STRING_ERROR_WRONGVERSION)));
 }
 
 /*------------------------------------------------------------------*/
-int error_network_problem(void)
+int
+error_network_problem (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_NETWORKPROBLEM)));
+  return (standard_error (lw_lang_string
+			  (LW_LANG_STRING_ERROR_NETWORKPROBLEM)));
 }
 
 /*------------------------------------------------------------------*/
-int error_cant_send_map(void)
+int
+error_cant_send_map (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_CANTSENDMAP)));
+  return (standard_error (lw_lang_string (LW_LANG_STRING_ERROR_CANTSENDMAP)));
 }
 
 /*------------------------------------------------------------------*/
-int error_cant_receive_map(void)
+int
+error_cant_receive_map (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_CANTRECEIVEMAP)));
+  return (standard_error (lw_lang_string
+			  (LW_LANG_STRING_ERROR_CANTRECEIVEMAP)));
 }
 
 /*------------------------------------------------------------------*/
-int error_server_full(void)
+int
+error_server_full (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_SERVERFULL)));
+  return (standard_error (lw_lang_string (LW_LANG_STRING_ERROR_SERVERFULL)));
 }
 
 /*------------------------------------------------------------------*/
-int error_bad_password(void)
+int
+error_bad_password (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_BADPASSWORD)));
+  return (standard_error (lw_lang_string (LW_LANG_STRING_ERROR_BADPASSWORD)));
 }
 
 /*------------------------------------------------------------------*/
-int error_bad_config_range(void)
+int
+error_bad_config_range (void)
 {
-  return (standard_error(lw_lang_string
-			 (LW_LANG_STRING_ERROR_BADCONFIGRANGE)));
+  return (standard_error (lw_lang_string
+			  (LW_LANG_STRING_ERROR_BADCONFIGRANGE)));
 }
-
-
-
