@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -100,7 +100,7 @@
 /* variables globales                                               */
 /*==================================================================*/
 
-int LW_GAME_RUNNING=0;
+int LW_GAME_RUNNING = 0;
 
 /*==================================================================*/
 /* fonctions                                                        */
@@ -110,17 +110,18 @@ int LW_GAME_RUNNING=0;
 /*
  * this function calculates how many teams will be playing
  */
-void calc_playing_teams(void)
+void
+calc_playing_teams (void)
 {
   int i;
 
-  PLAYING_TEAMS=0;
+  PLAYING_TEAMS = 0;
 
   /*
    * loop for all the possible teams, that's to say each of the
    * 6 areas in the "teams" menu
    */
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
       if (LW_NETWORK_ON)
 	{
@@ -133,7 +134,7 @@ void calc_playing_teams(void)
 	    }
 	}
       else
-	{ 
+	{
 	  /*
 	   * Not a network game, we only check the local config
 	   */
@@ -157,25 +158,26 @@ void calc_playing_teams(void)
 /*
  * associates a control method to a cursor
  */
-static void init_cursor_control_method (void)
+static void
+init_cursor_control_method (void)
 {
   int i;
 
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
       if (LW_NETWORK_ON)
 	{
-	  CURRENT_CURSOR[i].from_network=LW_NETWORK_INFO[i].network;
-	  CURRENT_CURSOR[i].control_type=LW_NETWORK_INFO[i].control_type;	  
+	  CURRENT_CURSOR[i].from_network = LW_NETWORK_INFO[i].network;
+	  CURRENT_CURSOR[i].control_type = LW_NETWORK_INFO[i].control_type;
 	}
       else
 	{
 	  /*
 	   * local teams
 	   */
-	  CURRENT_CURSOR[i].from_network=0;
-	  CURRENT_CURSOR[i].control_type=CONFIG_CONTROL_TYPE[i];
+	  CURRENT_CURSOR[i].from_network = 0;
+	  CURRENT_CURSOR[i].control_type = CONFIG_CONTROL_TYPE[i];
 	}
     }
 }
@@ -189,9 +191,10 @@ static void init_cursor_control_method (void)
  * checks if a team has lost the game, and make it leave the game
  * if necessary
  */
-int check_loose_team (void)
+int
+check_loose_team (void)
 {
-  int i=0,lost=0;
+  int i = 0, lost = 0;
 
   /*
    * loop for all the playing teams. we stop when we first find a
@@ -199,18 +202,18 @@ int check_loose_team (void)
    * be discovered at the next game round, so it's not a problem
    * and anyway, teams rarely loose at the same round 8-)
    */
-  while (i<PLAYING_TEAMS && !lost)
+  while (i < PLAYING_TEAMS && !lost)
     {
       /*
        * if there are no fighters left, then the game is lost
        */
-      if (ACTIVE_FIGHTERS[i]==0)
+      if (ACTIVE_FIGHTERS[i] == 0)
 	{
 	  /*
 	   * nothing will be calculated for this team anymore
 	   */
-	  eliminate_team(i);
-	  lost=1;
+	  eliminate_team (i);
+	  lost = 1;
 	}
       else
 	++i;
@@ -223,12 +226,12 @@ int check_loose_team (void)
       /*
        * sound effect
        */
-      play_loose();
+      play_loose ();
       /*
        * remove the team from the info bar, so that room if freed for 
        * other teams
        */
-      free_info_bar();
+      free_info_bar ();
     }
 
   return (lost);
@@ -243,20 +246,21 @@ int check_loose_team (void)
  * initialization of the game, the menu system has been leaved
  * and the game has to start right away
  */
-char  *init_game (void)
+char *
+init_game (void)
 {
   int i;
   int big_data;
-  int max_mem_reached=0;
-  int last_try=0;
-  int ok=0;
+  int max_mem_reached = 0;
+  int last_try = 0;
+  int ok = 0;
 
   /*
    * this string will be used to display error messages in case
    * something goes wrong. as long as message is not NULL it
    * the game can not be launched
    */
-  char *message=NULL;
+  char *message = NULL;
 
   /*
    * creation of a bitmap which represents the battlefield
@@ -265,15 +269,14 @@ char  *init_game (void)
    * no fighters drawn on it)
    */
   if (!message &&
-      (CURRENT_AREA_BACK=create_textured_map 
+      (CURRENT_AREA_BACK = lw_map_create_textured
        (CONFIG_LEVEL_MAP,
 	CONFIG_LEVEL_FG,
 	CONFIG_LEVEL_BG,
 	LW_NETWORK_ON,
 	MIN_MAP_RES_W[LW_CONFIG_CURRENT_RULES.min_map_res],
-	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res]))
-      ==NULL)
-    message=lw_lang_string(LW_LANG_STRING_GAME_BACKMEMFAIL);
+	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res])) == NULL)
+    message = lw_lang_string (LW_LANG_STRING_GAME_BACKMEMFAIL);
 
   /*
    * creation of the map which will be used for display
@@ -281,40 +284,39 @@ char  *init_game (void)
    * will be drawn on it
    */
   if (!message &&
-      (CURRENT_AREA_DISP=create_textured_map 
+      (CURRENT_AREA_DISP = lw_map_create_textured
        (CONFIG_LEVEL_MAP,
 	CONFIG_LEVEL_FG,
 	CONFIG_LEVEL_BG,
 	LW_NETWORK_ON,
 	MIN_MAP_RES_W[LW_CONFIG_CURRENT_RULES.min_map_res],
-	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res]))
-      ==NULL)
-    message=lw_lang_string(LW_LANG_STRING_GAME_DISPMEMFAIL);
+	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res])) == NULL)
+    message = lw_lang_string (LW_LANG_STRING_GAME_DISPMEMFAIL);
 
   if (!message)
     {
-      for (i=0;!max_mem_reached && !ok;++i)
+      for (i = 0; !max_mem_reached && !ok; ++i)
 	{
-	  message=NULL;
-	  reset_big_data();
+	  message = NULL;
+	  reset_big_data ();
 
 	  /*
 	   * creation of the mesh, see mesh.c for details
 	   */
-	  if (!message && create_mesh())
-	    message=lw_lang_string(LW_LANG_STRING_GAME_MESHMEMFAIL);
-      
+	  if (!message && create_mesh ())
+	    message = lw_lang_string (LW_LANG_STRING_GAME_MESHMEMFAIL);
+
 	  /*
 	   * creation of the game area, see area.c for details
 	   */
-	  if (!message && create_game_area())
-	    message=lw_lang_string(LW_LANG_STRING_GAME_AREAMEMFAIL);
-	  
+	  if (!message && create_game_area ())
+	    message = lw_lang_string (LW_LANG_STRING_GAME_AREAMEMFAIL);
+
 	  /*
 	   * creation of the armies, see army.c for details
 	   */
-	  if (!message && create_army())
-	    message=lw_lang_string(LW_LANG_STRING_GAME_ARMYMEMFAIL);
+	  if (!message && create_army ())
+	    message = lw_lang_string (LW_LANG_STRING_GAME_ARMYMEMFAIL);
 
 	  if (message)
 	    {
@@ -328,21 +330,21 @@ char  *init_game (void)
 		   * allocate all we wanted to, and this is not
 		   * enough -> we give up...
 		   */
-		  max_mem_reached=0;
+		  max_mem_reached = 0;
 		}
 	      else
 		{
 		  /*
 		   * We increase the amount of allocated memory
 		   */
-		  STARTUP_BIG_DATA+=LW_STARTUP_MEM_STEP;
-		  if (STARTUP_BIG_DATA>LW_STARTUP_MEM_MAX)
+		  STARTUP_BIG_DATA += LW_STARTUP_MEM_STEP;
+		  if (STARTUP_BIG_DATA > LW_STARTUP_MEM_MAX)
 		    {
-		      last_try=1;
-		      STARTUP_BIG_DATA=LW_STARTUP_MEM_MAX;
+		      last_try = 1;
+		      STARTUP_BIG_DATA = LW_STARTUP_MEM_MAX;
 		    }
-		  big_data=STARTUP_BIG_DATA;
-		  if (malloc_big_data())
+		  big_data = STARTUP_BIG_DATA;
+		  if (malloc_big_data ())
 		    {
 		      if (STARTUP_BIG_DATA != big_data)
 			{
@@ -351,7 +353,7 @@ char  *init_game (void)
 			   * allocated, we consider this is
 			   * the last try.
 			   */
-			  last_try=1;
+			  last_try = 1;
 			}
 		    }
 		  else
@@ -359,13 +361,13 @@ char  *init_game (void)
 		      /*
 		       * memory allocation failed...
 		       */
-		      max_mem_reached=1;
+		      max_mem_reached = 1;
 		    }
 		}
 	    }
 	  else
 	    {
-	      ok=1;
+	      ok = 1;
 	    }
 	}
     }
@@ -380,12 +382,12 @@ char  *init_game (void)
        * and should never fail
        * check each function to know what it does!!!
        */
-      reset_mesh();
-      reset_game_area();
-      reset_all_cursor();
+      reset_mesh ();
+      reset_game_area ();
+      reset_all_cursor ();
       init_cursor_control_method ();
-      place_all_team();
-      init_move_fighters();
+      place_all_team ();
+      init_move_fighters ();
       init_disp_cursor ();
     }
 
@@ -393,7 +395,7 @@ char  *init_game (void)
    * We set the network error flag to 0, if it becomes non-zero
    * then the game simply stops...
    */
-  LW_NETWORK_ERROR_DETECTED=0;
+  LW_NETWORK_ERROR_DETECTED = 0;
 
   return message;
 }
@@ -404,7 +406,8 @@ char  *init_game (void)
  * currently only the bitmaps have to be freed since mesh, maps etc...
  * are allocated in the "big data" structure (bigdata.c)
  */
-void free_game_memory (void)
+void
+free_game_memory (void)
 {
   /*
    * the info bar allocates bitmaps for its display, get rid of'm
@@ -423,7 +426,7 @@ void free_game_memory (void)
   if (CURRENT_AREA_DISP)
     {
       destroy_bitmap (CURRENT_AREA_DISP);
-      CURRENT_AREA_DISP=0;
+      CURRENT_AREA_DISP = 0;
     }
   /*
    * free the clean empty bitmap if it exists
@@ -431,7 +434,7 @@ void free_game_memory (void)
   if (CURRENT_AREA_BACK)
     {
       destroy_bitmap (CURRENT_AREA_BACK);
-      CURRENT_AREA_BACK=0;
+      CURRENT_AREA_BACK = 0;
     }
 }
 
@@ -443,42 +446,43 @@ void free_game_memory (void)
  * might be dirty, so we artificially simulate a round
  * this is just about display, no logic operations
  */
-int blank_round(void)
+int
+blank_round (void)
 {
   /*
    * the first call to page flip allocates a bitmap for drawing,
    * so it might fail...
    */
-  if (page_flip())
+  if (page_flip ())
     {
       /*
        * the distorsion displayer is used for the wave effect
        */
-      init_distorsion_displayer();
+      init_distorsion_displayer ();
       /*
        * prepares the basic layer for the first buffer
        */
-      display_back_image();
+      display_back_image ();
       rect_for_viewport ();
       /*
        * displays the map in the previously defined layer
        */
-      disp_all_cursors();
-      display_area();
-      undisp_all_cursors();
+      disp_all_cursors ();
+      display_area ();
+      undisp_all_cursors ();
       /*
        * we now show what we have done to the player
        */
-      page_flip();
+      page_flip ();
       /*
        * prepares the basic layer for the second buffer
        */
-      display_back_image();
+      display_back_image ();
       rect_for_viewport ();
       /*
        * clean up message queue
-       */ 
-      clear_message();
+       */
+      clear_message ();
       return 0;
     }
   else
@@ -491,27 +495,28 @@ int blank_round(void)
  * can display the map or special screens if we are in some
  * sort of debug mode
  */
-static void fill_next_screen (void)
+static void
+fill_next_screen (void)
 {
   /*
    * GRAD_TO_DISP is the gradient we want to show
    * normally no gradient is displayed, so the gradient is 0
    */
-  if (GRAD_TO_DISP==0)
+  if (GRAD_TO_DISP == 0)
     {
       /*
        * we add the cursors to the map, temporary
        */
-      disp_all_cursors();
+      disp_all_cursors ();
       /*
        * physical drawing of the map
        */
-      display_area();
+      display_area ();
       /*
        * we remove the cursors, for they might move next time
        * so they are no longer required
        */
-      undisp_all_cursors();
+      undisp_all_cursors ();
     }
 
   /*
@@ -519,15 +524,15 @@ static void fill_next_screen (void)
    * the selected team, this way one can see in real tiem how
    * the gradient is calculated. for curious guys
    */
-  if (GRAD_TO_DISP>=1 && GRAD_TO_DISP<=6)
-    display_gradient(GRAD_TO_DISP-1);
+  if (GRAD_TO_DISP >= 1 && GRAD_TO_DISP <= 6)
+    display_gradient (GRAD_TO_DISP - 1);
 
   /*
    * is GRAD_TO_DISP is 7 or 8 we display the plain mesh with
    * various display options
    */
-  if (GRAD_TO_DISP>=7 && GRAD_TO_DISP<=8)
-    display_mesh(GRAD_TO_DISP-7);
+  if (GRAD_TO_DISP >= 7 && GRAD_TO_DISP <= 8)
+    display_mesh (GRAD_TO_DISP - 7);
 }
 
 /*------------------------------------------------------------------*/
@@ -539,7 +544,8 @@ static void fill_next_screen (void)
  * "game round" has ellapsed. indeed, it's here that the global
  * GLOBAL_CLOCK is incremented 8-)
  */
-static void logic(void)
+static void
+logic (void)
 {
   /*
    * if the game is paused, we do not do everything
@@ -551,12 +557,12 @@ static void logic(void)
        * moves the cursors. this will ask the keyboard module
        * for information, ask the AI functions what to do...
        */
-      move_all_cursors();
+      move_all_cursors ();
       /*
        * applying the cursors means that we communicate to
        * the game area the information about where the cursors are
        */
-      apply_all_cursor();
+      apply_all_cursor ();
     }
   /*
    * the profile module enables CPU time tracking, so that the player
@@ -571,7 +577,7 @@ static void logic(void)
        * on where the cursors are, this information being given
        * by apply_all_cursor
        */
-      spread_single_gradient();
+      spread_single_gradient ();
     }
   /*
    * this call ends the time tracking associated to the spread function
@@ -585,7 +591,7 @@ static void logic(void)
        * now we move the fighters, ie each fighter of each team
        * will either move, attack his neighbor, die...
        */
-      move_fighters();
+      move_fighters ();
     }
 
   stop_profile (MOVE_PROFILE);
@@ -598,7 +604,7 @@ static void logic(void)
        * This code used to be in the "display" functions, which
        * is a very bad idea for it caused network inconsistencies...
        */
-      check_loose_team();
+      check_loose_team ();
     }
 
   /*
@@ -620,7 +626,8 @@ static void logic(void)
  * this function does also other things than display, in fact it does
  * everything which is not directly linked to a game cycle
  */
-static void display(void)
+static void
+display (void)
 {
   /*
    * the watchdog waits for secret codes to be entered
@@ -629,12 +636,12 @@ static void display(void)
    * keypressed() and so will also automatically call poll_keyboard()
    * if needed.
    */
-  watchdog_update();
+  watchdog_update ();
   /*
    * calls the watchdog module to see if a secret code has been
    * entered, and does the required stuff if the answer is yes
    */
-  check_code();
+  check_code ();
   /*
    * keeps track of how long the mext operation takes
    */
@@ -642,7 +649,7 @@ static void display(void)
   /*
    * now we call the function that actually draws stuff
    */
-  fill_next_screen();
+  fill_next_screen ();
   stop_profile (DISP_PROFILE);
 
   /*
@@ -650,19 +657,19 @@ static void display(void)
    * ie it detects if F1 has been pressed and decides wether
    * the info bar must be displayed or not
    */
-  check_info_state();
+  check_info_state ();
 
   /*
    * updates some time values, telling how many weeks this tremendous
    * liquid war session has been running 8-) 
    */
-  update_play_time();
+  update_play_time ();
 
   /*
    * Now this is a little trick, we change the order of display
    * depending on the capture mode.
    */
-  if (lw_capture_get_mode())
+  if (lw_capture_get_mode ())
     {
       /*
        * We're in capture mode: we display info before the dump
@@ -671,8 +678,8 @@ static void display(void)
        * video capture.
        */
       display_info ();
-      lw_capture_dump_game();
-      display_message();
+      lw_capture_dump_game ();
+      display_message ();
     }
   else
     {
@@ -681,7 +688,7 @@ static void display(void)
        * for displaying them after the info might give them an
        * ugly blinking look if we're not in double-buffered mode.
        */
-      display_message();
+      display_message ();
       display_info ();
     }
 
@@ -701,40 +708,41 @@ static void display(void)
 /*
  * *THE* main game loop
  */
-int game (void)
+int
+game (void)
 {
-  int retour=0;
-  int last_display_time=get_ticker();
-  int last_logic_time=get_ticker();
+  int retour = 0;
+  int last_display_time = get_ticker ();
+  int last_logic_time = get_ticker ();
   int lr;
 
   /*
    * we initialize the time module telling him that now it's 0
    * and he it can start recording stuff
    */
-  start_play_time();
+  start_play_time ();
   /*
    * resets the secret code sequences
    */
-  watchdog_reset();
-  reset_code();
+  watchdog_reset ();
+  reset_code ();
   /*
    * resets input buffers and control interfaces
    */
-  lw_mouse_reset_control();
+  lw_mouse_reset_control ();
   reset_computer_path ();
   /*
    * resets profile information, so that they are not affected
    * by previous games
    */
-  reset_all_profile();
+  reset_all_profile ();
 
   /*
    * everything's ready, POOOOOOOOOT the game starts and you hear it
    */
-  play_go();
+  play_go ();
 
-  if (1/*!init_distorsion_displayer()*/)
+  if (1 /*!init_distorsion_displayer() */ )
     {
       /*
        * so we loop (almost) for ever
@@ -743,10 +751,9 @@ int game (void)
        * - there are less than 2 teams playing, ie there's a winner
        * - the game time is elapsed
        */
-      while (  (!WATCHDOG_SCANCODE[KEY_ESC])
-	       && (PLAYING_TEAMS>=2)
-	       && (TIME_LEFT>0)
-	       && (!LW_NETWORK_ERROR_DETECTED))
+      while ((!WATCHDOG_SCANCODE[KEY_ESC])
+	     && (PLAYING_TEAMS >= 2)
+	     && (TIME_LEFT > 0) && (!LW_NETWORK_ERROR_DETECTED))
 	{
 	  /*
 	   * global time checking
@@ -756,27 +763,26 @@ int game (void)
 	  /*
 	   * will contain how mush called to logic have been performed
 	   */
-	  lr=0;
+	  lr = 0;
 	  do
 	    {
 	      /*
 	       * we call logic, calculates stuff, move players etc...
 	       */
-	      logic();
+	      logic ();
 
 	      /*
 	       * Now we decide to go idel if it happens that the computer
 	       * is calculating this "too fast". This will enable people
 	       * too play Liquid War even on a very very fast machine
 	       */
-	      while (get_ticker() < last_logic_time
-		     +LOGIC_DELAY_MIN
-		     [CONFIG_ROUNDS_PER_SEC_LIMIT])
+	      while (get_ticker () < last_logic_time
+		     + LOGIC_DELAY_MIN[CONFIG_ROUNDS_PER_SEC_LIMIT])
 		{
-		  rest(1);
-		  yield_timeslice();
-		}	      
-	      last_logic_time=get_ticker();
+		  rest (1);
+		  yield_timeslice ();
+		}
+	      last_logic_time = get_ticker ();
 
 	      lr++;
 	    }
@@ -792,29 +798,29 @@ int game (void)
 	     * and keep the rest of the CPU for calls to logic()
 	     */
 	    (CONFIG_FRAMES_PER_SEC_LIMIT
-	     && (get_ticker() <last_display_time
-		 +DISPLAY_DELAY_MIN
-		 [CONFIG_FRAMES_PER_SEC_LIMIT]));
+	     && (get_ticker () < last_display_time
+		 + DISPLAY_DELAY_MIN[CONFIG_FRAMES_PER_SEC_LIMIT]));
 	  /*
 	   * tells the profile module about how much logic operations
 	   * have been done for this display
 	   */
-	  update_logic_rate(lr);
+	  update_logic_rate (lr);
 
 	  /*
 	   * we get the information "when has the last call to display() 
 	   * been done"
 	   */
-	  last_display_time=get_ticker();
+	  last_display_time = get_ticker ();
+
 	  /*
 	   * now we really display stuff, (takes time...)
 	   */
-	  display();
+	  display ();
 
 	  /*
 	   * Now we check if the "Close" button has been clicked
 	   */
-	  my_exit_poll();
+	  my_exit_poll ();
 
 	  stop_profile (GLOBAL_PROFILE);
 	}
@@ -822,7 +828,7 @@ int game (void)
   /*
    * cleans up the double buffer system
    */
-  last_flip();
+  last_flip ();
 
   /*
    * empties the key buffer
