@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -61,6 +61,7 @@
 #include "log.h"
 #include "sockgen.h"
 #include "sock2gen.h"
+#include "macro.h"
 
 /*==================================================================*/
 /* constants                                                        */
@@ -69,8 +70,18 @@
 #define LW_HTTPUTIL_PORT              80
 #define LW_HTTPUTIL_HOST_SIZE         200
 #define LW_HTTPUTIL_REQUEST_SIZE      1000
-#define LW_HTTPUTIL_GET_HTTP          "GET http://"
 #define LW_HTTPUTIL_EMPTY_LINES_LIMIT 10
+#define LW_HTTPUTIL_MIN_LEN           1
+#define LW_HTTPUTIL_GET_CMD \
+    "GET http://%s HTTP/1.1\r\n" \
+    "Host: %s\r\n" \
+    "Connection: close\r\n"
+/* additional CR+LF supplied by lw_sock_send_str() */
+/*
+ * Note: I replaced the original "\x0d\x0a" that where in the
+ * patch by the equivalent "\r\n". I find it more readable,
+ * that's all 8-)
+ */
 
 /*==================================================================*/
 /* static functions                                                 */
@@ -86,79 +97,116 @@
  * If there's an error, the error message is written in "content".
  * If there's no error, "content" contains the web page.
  */
-int lw_httputil_get_page(char *content, char *url, int size)
+int
+lw_httputil_get_page (char *content, char *url, int size)
 {
-  int result=0;
+  int result = 0;
   char ip[LW_SOCK_IP_SIZE];
-  char host[LW_HTTPUTIL_HOST_SIZE+1];
-  char request[LW_HTTPUTIL_REQUEST_SIZE+1];
+  char host[LW_HTTPUTIL_HOST_SIZE + 1];
+  char request[LW_HTTPUTIL_REQUEST_SIZE + 1];
   char data[LW_SOCK_MESSAGE_SIZE];
+  int data_len;
   char *search;
   int sock;
-  int empty_lines=0;
+  int empty_lines = 0;
 
-  memset(content,0,size);
+  memset (content, 0, size);
 
-  strncpy(host,url,LW_HTTPUTIL_HOST_SIZE);
-  host[LW_HTTPUTIL_HOST_SIZE]='\0';
-  search=strchr(host,'/');
+  LW_MACRO_STRCPY (host, url);
+
+  search = strchr (host, '/');
   if (search)
     {
-      (*search)='\0';
-    }
-  
-  strcpy(request,LW_HTTPUTIL_GET_HTTP);
-  if (strlen(url)+strlen(request)<LW_HTTPUTIL_REQUEST_SIZE)
-    {
-      strcat(request,url);
+      (*search) = '\0';
     }
 
-  if (lw_dnsutil_name_to_ip(ip,host))
+  LW_MACRO_SPRINTF2 (request, LW_HTTPUTIL_GET_CMD, url, host);
+
+  if (lw_dnsutil_name_to_ip (ip, host))
     {
-      if (lw_sock_connect(&sock, ip, LW_HTTPUTIL_PORT))
+      if (lw_sock_connect (&sock, ip, LW_HTTPUTIL_PORT))
 	{
-	  if (lw_sock_send_str(sock,request))
+	  if (lw_sock_send_str (sock, request))
 	    {
-	      while (lw_sock_recv_str(sock,data)==1 && 
-		     empty_lines<LW_HTTPUTIL_EMPTY_LINES_LIMIT)
+	      result = 1;
+	      /* read status line */
+	      if (result && lw_sock_recv_str (sock, data) != 1)
 		{
-		  if (strlen(content)+strlen(data)<size-2)
+		  result = 0;
+		  LW_MACRO_SNPRINTF0 (content, size,
+				      "Failed to read status line");
+		}
+	      /* make sure status code starts with 2 */
+	      if (result &&
+		  !((search = strchr (data, ' ')) && search[1] == '2'))
+		{
+		  result = 0;
+		  LW_MACRO_SNPRINTF2 (content, size,
+				      "Failure from web server \"%s\": \"%s\"",
+				      host, data);
+		}
+	      if (result)
+		{
+		  /* skip past headers */
+		  while ((result =
+			  (result && (lw_sock_recv_str (sock, data) == 1))) &&
+			 data[0])
 		    {
-		      strcat(content,data);
-		      strcat(content,"\n");
+		      /* nothing to do here */
 		    }
-		  if (strlen(data)==0)
+
+		  if (result)
 		    {
-		      empty_lines++;
+		      /* finally, we read the list of servers */
+		      while (lw_sock_recv_str (sock, data) == 1 &&
+			     empty_lines < LW_HTTPUTIL_EMPTY_LINES_LIMIT)
+			{
+			  data_len = strlen (data);
+			  /*
+			   * If the line is too short, we ignore it,
+			   * in fact, we get many "too short" lines
+			   * such as the size of the file for instance,
+			   * which is shown as an hex number in HTTP 1.1
+			   *
+			   * No "usefull" line should be smaller than 
+			   * LW_HTTPUTIL_MIN_LEN however.
+			   */
+			  if (data_len > LW_HTTPUTIL_MIN_LEN)
+			    {
+			      if ((int) (strlen (content) + data_len) <
+				  size - 2)
+				{
+				  LW_MACRO_STRNCAT (content, data, size);
+				  LW_MACRO_STRNCAT (content, "\n", size);
+				}
+			    }
+			  if (data_len == 0)
+			    {
+			      empty_lines++;
+			    }
+			}
+		    }
+		  else
+		    {
+		      LW_MACRO_SNPRINTF0 (content, size,
+					  "Failed to read headers");
 		    }
-		  result=1;
 		}
 	    }
-
-	  lw_sock_close(&sock);
-
-	  if (!result)
+	  else
 	    {
-	      if (size>strlen(request)+100)
-		{
-		  sprintf(content,"Request \"%s\" failed!",request);
-		}
+	      LW_MACRO_SNPRINTF1 (content, size, "Request \"%s\" failed!",
+				  request);
 	    }
 	}
       else
 	{
-	  if (size>strlen(ip)+100)
-	    {
-	      sprintf(content,"Can't connect to \"%s\"!",ip);
-	    }
+	  LW_MACRO_SNPRINTF1 (content, size, "Can't connect to \"%s\"!", ip);
 	}
     }
   else
     {
-      if (size>strlen(host)+100)
-	{
-	  sprintf(content,"Unable to find host \"%s\"!",host);
-	}
+      LW_MACRO_SNPRINTF1 (content, size, "Unable to find host \"%s\"!", host);
     }
 
   return result;
@@ -173,42 +221,42 @@ int lw_httputil_get_page(char *content, char *url, int size)
  * easily people to submit spaces while using command line arguments
  * with the server.
  */
-void lw_httputil_text_to_urlparam(char *urlparam, char *text, int size)
+void
+lw_httputil_text_to_urlparam (char *urlparam, char *text, int size)
 {
-  int i,j;
+  int i, j;
   char buffer[33];
   unsigned char c;
 
-  memset(urlparam,0,size+1);
+  memset (urlparam, 0, size + 1);
 
-  j=0;
-  for (i=0;text[i] && j<size;++i)
+  j = 0;
+  for (i = 0; text[i] && j < size; ++i)
     {
-      if (text[i]=='_')
+      if (text[i] == '_')
 	{
-	  c=' ';
+	  c = ' ';
 	}
       else
 	{
-	  c=text[i];
+	  c = text[i];
 	}
 
-      if (isalnum(c))
+      if (isalnum (c))
 	{
-	  urlparam[j]=c;
+	  urlparam[j] = c;
 	  j++;
 	}
       else
 	{
-	  if (j<size-2)
+	  if (j < size - 2)
 	    {
-	      sprintf(buffer,"%X",c);
-	      urlparam[j]='%';
-	      urlparam[j+1]=buffer[0];
-	      urlparam[j+2]=buffer[1];
+	      LW_MACRO_SPRINTF1 (buffer, "%X", c);
+	      urlparam[j] = '%';
+	      urlparam[j + 1] = buffer[0];
+	      urlparam[j + 2] = buffer[1];
 	    }
-	  j+=3;
+	  j += 3;
 	}
     }
 }
-
