@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -56,6 +56,7 @@
 #include <stdlib.h>
 #include <time.h>
 
+#include "base.h"
 #include "config.h"
 #include "gfxmode.h"
 #include "init.h"
@@ -78,177 +79,177 @@
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-void display_success (int success)
+void
+display_success (int success)
 {
   if (success)
     log_println_str (" - success!");
   else
-    log_println_str (" - failed...");  
+    log_println_str (" - failed...");
 
-  log_flush();
-  /* delay (100);*/
+  log_flush ();
+  /* delay (100); */
 }
 
 /*------------------------------------------------------------------*/
-void display_success_driver (char *driver)
+void
+display_success_driver (char *driver)
 {
-  log_print_str(" (driver=\"");
-  log_print_str(driver);
+  log_print_str (" (driver=\"");
+  log_print_str (driver);
   log_println_str ("\") - success!");
 
-  log_flush();
-  /* delay (100);*/
+  log_flush ();
+  /* delay (100); */
 }
 
 /*------------------------------------------------------------------*/
-int init_all ()
+int
+init_all ()
 {
-  int result=0;
-  int assembly=1,config=1,timer=1,keyboard=1,mouse=1,sound=1,joystick=1,network=1;
+  int result = 0;
+  int assembly = 1, config = 1, timer = 1, keyboard = 1, mouse = 1, sound =
+    1, joystick = 1, network = 1;
 
   /*
-   * we use srand to garantee that rand() won't return the same values
+   * we use srand to garantee that random() won't return the same values
    * each time the game is run
    */
-  srand(time(NULL));
+  srandom (time (NULL));
 
-  set_startup();
-  log_init();
-  lw_lang_init();
-  set_uformat(U_ASCII);
+  set_startup ();
+  log_init ();
+  lw_lang_init ();
+  set_uformat (U_ASCII);
 
   allegro_init ();
 #ifdef ALLEGRO_DOS
   set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
 #endif
-  log_println_str ("Starting Allegro (http://www.talula.demon.co.uk/allegro)");
-  log_println();
-  log_print_str("Allegro ID : ");
-  log_println_str(allegro_id);
-  log_println();
+  log_println_str
+    ("Starting Allegro (http://www.talula.demon.co.uk/allegro)");
+  log_println ();
+  log_print_str ("Allegro ID : ");
+  log_println_str (allegro_id);
+  log_println ();
 
-  set_color_depth(8);
-  set_color_conversion(COLORCONV_REDUCE_TO_256);
+  set_color_depth (8);
+  set_color_conversion (COLORCONV_REDUCE_TO_256);
 
   /*
    * We check for potential struct size errors
    */
-  assembly=lw_asm_check_struct_align();
+  assembly = lw_asm_check_struct_align ();
+
+  log_print_str ("Loading config options from \"");
+  log_print_str (STARTUP_CFG_PATH);
+  log_print_str ("\"");
 
-  log_print_str("Loading config options from \"");
-  log_print_str(STARTUP_CFG_PATH);
-  log_print_str("\"");
- 
   /*
    * We call this now only (after loading the options), for
    * options must be loaded for my_exit_close_button to work
    */
-  set_window_close_button(TRUE);
-  set_window_close_hook(my_exit_close_button);
+  set_window_close_button (TRUE);
+  set_window_close_hook (my_exit_close_button);
 
-  display_success (config=load_config_options());
+  display_success (config = load_config_options ());
 
-  log_print_str("Installing timer");
-  timer=!install_timer ();
+  log_print_str ("Installing timer");
+  timer = !install_timer ();
   if (timer)
     {
-      display_success_driver((char *) timer_driver->ascii_name);
+      display_success_driver ((char *) timer_driver->ascii_name);
     }
   else
     {
-      display_success(0);
+      display_success (0);
     }
 
-  start_ticker();
+  start_ticker ();
 
-  log_print_str("Installing keyboard");
-  keyboard=!install_keyboard ();
+  log_print_str ("Installing keyboard");
+  keyboard = !install_keyboard ();
   if (keyboard)
     {
-      display_success_driver((char *) keyboard_driver->ascii_name);
+      display_success_driver ((char *) keyboard_driver->ascii_name);
     }
   else
     {
-      display_success(0);
+      display_success (0);
     }
 
-  log_print_str("Installing mouse");
-  mouse=install_mouse()!=-1;
+  log_print_str ("Installing mouse");
+  mouse = install_mouse () != -1;
   if (mouse)
     {
-      display_success_driver((char *) mouse_driver->ascii_name);
+      display_success_driver ((char *) mouse_driver->ascii_name);
     }
   else
     {
-      display_success(0);
+      display_success (0);
     }
 
   if (STARTUP_DIGI_CARD != DIGI_NONE || STARTUP_MIDI_CARD != MIDI_NONE)
     {
       log_print_str ("Installing sound");
-      sound=!install_sound(STARTUP_DIGI_CARD,STARTUP_MIDI_CARD,"");
-      if (!sound) 
+      sound = !install_sound (STARTUP_DIGI_CARD, STARTUP_MIDI_CARD, "");
+      if (!sound)
 	{
 	  /*
 	   * OK, first init failed, now we try without the MIDI card, which
 	   * is where problems usually come from, especially under Linux
 	   */
-	  sound=!install_sound(STARTUP_DIGI_CARD, MIDI_NONE, "");
+	  sound = !install_sound (STARTUP_DIGI_CARD, MIDI_NONE, "");
 	}
-      if (sound) 
+      if (sound)
 	{
-	  log_print_str(" (digi=\"");
-	  log_print_str((char *) digi_driver->ascii_name);
-	  log_print_str("\", midi=\"");
-	  log_print_str((char *) midi_driver->ascii_name);
-	  log_print_str("\")");
-	} 
-      display_success(sound);
+	  log_print_str (" (digi=\"");
+	  log_print_str ((char *) digi_driver->ascii_name);
+	  log_print_str ("\", midi=\"");
+	  log_print_str ((char *) midi_driver->ascii_name);
+	  log_print_str ("\")");
+	}
+      display_success (sound);
     }
 
   if (STARTUP_JOYSTICK_ON)
     {
       log_print_str ("Installing joystick");
       if (STARTUP_JOYSTICK_ON)
-	joystick=!my_initialise_joystick ();
+	joystick = !my_initialise_joystick ();
       if (joystick)
 	{
-	  display_success_driver((char *) joystick_driver->ascii_name);
+	  display_success_driver ((char *) joystick_driver->ascii_name);
 	}
       else
 	{
-	  display_success(0);
+	  display_success (0);
 	}
     }
 
-  log_print_str("Setting up network");
-  display_success(network=lw_sock_init());
+  log_print_str ("Setting up network");
+  display_success (network = lw_sock_init ());
 
   /*
    * We update the "capture" mode
    */
-  lw_capture_set_mode(STARTUP_CAPTURE);
+  lw_capture_set_mode (STARTUP_CAPTURE);
 
-  result= (assembly || !STARTUP_CHECK) 
+  result = (assembly || !STARTUP_CHECK)
     && timer
     && keyboard
-    && mouse
-    && (sound || !STARTUP_CHECK)
-    && (joystick || !STARTUP_CHECK);
+    && mouse && (sound || !STARTUP_CHECK) && (joystick || !STARTUP_CHECK);
 
   return (result);
 }
 
 /*------------------------------------------------------------------*/
-int start_graphic (void)
+int
+start_graphic (void)
 {
   int retour;
 
-  retour= (!set_resolution (CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN,NULL));
+  retour = (!set_resolution (CONFIG_GFX_MENU, 0, CONFIG_FULLSCREEN, NULL));
 
   return retour;
 }
-
-
-
-  
