@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -59,8 +59,9 @@
 #include <string.h>
 
 #include "lang.h"
-#include "langfr.h"
+#include "langde.h"
 #include "langen.h"
+#include "langfr.h"
 #include "config.h"
 
 /*==================================================================*/
@@ -70,37 +71,42 @@
 /*------------------------------------------------------------------*/
 /* initializes the string tables                                    */
 /*------------------------------------------------------------------*/
-void lw_lang_init()
+void
+lw_lang_init ()
 {
-  lw_langfr_init();
-  lw_langen_init();
+  lw_langde_init ();
+  lw_langen_init ();
+  lw_langfr_init ();
 }
 
 /*------------------------------------------------------------------*/
 /* returns the string associated to an id                           */
 /*------------------------------------------------------------------*/
-char *lw_lang_string(int id)
+char *
+lw_lang_string (int id)
 {
-  char *result=NULL;
+  char *result = NULL;
   int language;
 
-  language = (CONFIG_LANGUAGE==LW_LANG_LANGUAGE_AUTO)
-    ? lw_lang_auto()
-    : CONFIG_LANGUAGE;
+  language = (CONFIG_LANGUAGE == LW_LANG_LANGUAGE_AUTO)
+    ? lw_lang_auto () : CONFIG_LANGUAGE;
 
   switch (language)
     {
+    case LW_LANG_LANGUAGE_DEUTSCH:
+      result = lw_langde_string (id);
+      break;
     case LW_LANG_LANGUAGE_ENGLISH:
-      result=lw_langen_string(id);
+      result = lw_langen_string (id);
       break;
     case LW_LANG_LANGUAGE_FRANCAIS:
-      result=lw_langfr_string(id);      
+      result = lw_langfr_string (id);
       break;
     }
 
   if (!result)
     {
-      result="???";
+      result = "???";
     }
 
   return result;
@@ -109,23 +115,27 @@ char *lw_lang_string(int id)
 /*------------------------------------------------------------------*/
 /* returns the string associated to a given language                */
 /*------------------------------------------------------------------*/
-char *lw_lang_language(int lang)
+char *
+lw_lang_language (int lang)
 {
-  char *result=NULL;
+  char *result = NULL;
 
   switch (lang)
     {
+    case LW_LANG_LANGUAGE_DEUTSCH:
+      result = lw_langde_string (LW_LANG_STRING_LANGUAGE);
+      break;
     case LW_LANG_LANGUAGE_ENGLISH:
-      result=lw_langen_string(LW_LANG_STRING_LANGUAGE);
+      result = lw_langen_string (LW_LANG_STRING_LANGUAGE);
       break;
     case LW_LANG_LANGUAGE_FRANCAIS:
-      result=lw_langfr_string(LW_LANG_STRING_LANGUAGE);      
+      result = lw_langfr_string (LW_LANG_STRING_LANGUAGE);
       break;
     }
 
   if (!result)
     {
-      result="???";
+      result = "???";
     }
 
   return result;
@@ -134,31 +144,42 @@ char *lw_lang_language(int lang)
 /*------------------------------------------------------------------*/
 /* returns the "automatic" language code                            */
 /*------------------------------------------------------------------*/
-int lw_lang_auto()
+int
+lw_lang_auto ()
 {
   int language;
 
   /*
    * By default, we speak English
    */
-  language=LW_LANG_LANGUAGE_ENGLISH;
-  
+  language = LW_LANG_LANGUAGE_ENGLISH;
+
 #ifdef UNIX
   {
     char *env_lang;
-    
-    env_lang=getenv("LANG");
-    
-    if (env_lang!=NULL)
+
+    env_lang = getenv ("LANG");
+
+    if (env_lang != NULL)
       {
+	/*
+	 * We try and check if LANG is set to "DE..." to enable German
+	 * support.
+	 */
+	if (strncmp (env_lang, "DE", 2) == 0 ||
+	    strncmp (env_lang, "de", 2) == 0)
+	  {
+	    language = LW_LANG_LANGUAGE_DEUTSCH;
+	  }
+
 	/*
 	 * We try and check if LANG is set to "FR..." to enable French
 	 * support.
 	 */
-	if (strncmp(env_lang,"FR",2) == 0 || 
-	    strncmp(env_lang,"fr",2) == 0)
-	  { 
-	    language=LW_LANG_LANGUAGE_FRANCAIS;
+	if (strncmp (env_lang, "FR", 2) == 0 ||
+	    strncmp (env_lang, "fr", 2) == 0)
+	  {
+	    language = LW_LANG_LANGUAGE_FRANCAIS;
 	  }
       }
   }
@@ -168,7 +189,7 @@ int lw_lang_auto()
   {
     int lang_id;
 
-    lang_id=GetSystemDefaultLangID();
+    lang_id = GetSystemDefaultLangID ();
 
     /*
      * Lists of some Windows language codes, 
@@ -180,17 +201,30 @@ int lw_lang_auto()
      * 0x100c French (Switzerland) 
      * 0x140c French (Luxembourg) 
      * 0x180c Windows 98/Me, Windows 2000/XP: French (Monaco)
+     *
+     * 0x0407 German (Standard) 
+     * 0x0807 German (Switzerland) 
+     * 0x0c07 German (Austria) 
+     * 0x1007 German (Luxembourg) 
+     * 0x1407 German (Liechtenstein)
      */
-    
+
     switch (lang_id)
       {
+      case 0x0407:
+      case 0x0807:
+      case 0x0c07:
+      case 0x1007:
+      case 0x1407:
+	language = LW_LANG_LANGUAGE_DEUTSCH;
+	break;
       case 0x040c:
       case 0x080c:
       case 0x0c0c:
       case 0x100c:
       case 0x140c:
       case 0x180c:
-	language=LW_LANG_LANGUAGE_FRANCAIS;
+	language = LW_LANG_LANGUAGE_FRANCAIS;
 	break;
       }
   }
