@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -67,13 +67,13 @@
 /* fonctions globales                                               */
 /*==================================================================*/
 
-void *archive_raw_map (const char *filename);
-BITMAP *create_bicolor_map (int num, int fg, int bg, 
-			    int network, int min_w, int min_h);
-BITMAP *create_textured_map (int num, int fg, int bg, 
-			     int network, int min_w, int min_h);
-char *get_map_readable_name (int num, int network);
-void get_map_res (int num,int *w,int *h, 
-		  int network, int min_w, int min_h);
+void *lw_map_archive_raw (const char *filename);
+BITMAP *lw_map_create_bicolor (int num, int fg, int bg,
+			       int network, int min_w, int min_h);
+BITMAP *lw_map_create_textured (int num, int fg, int bg,
+				int network, int min_w, int min_h);
+char *lw_map_get_readable_name (int num, int network);
+void lw_map_get_res (int num, int *w, int *h,
+		     int network, int min_w, int min_h);
 
 #endif
