@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -83,18 +83,19 @@
  * moves a cursor in a given direction if the place is free
  * one just has to give the x & y values of the cursors as params
  */
-static int move_if_free (int *x, int *y, int dir)
+static int
+move_if_free (int *x, int *y, int dir)
 {
-  int moved=0;
+  int moved = 0;
 
   /*
    * we check if the direction is between 1 and 8
    * if not force it into this range
    */
-  while (dir>8)
-    dir-=8;
-  while (dir<1)
-    dir+=8;
+  while (dir > 8)
+    dir -= 8;
+  while (dir < 1)
+    dir += 8;
 
   /*
    * switch between all dirs
@@ -111,78 +112,86 @@ static int move_if_free (int *x, int *y, int dir)
       /*
        * trying to go NORTH
        */
-    case 1: if (CURRENT_AREA[((*y)-1)*CURRENT_AREA_W+(*x)].mesh)
-      {
-	(*y)--;
-	moved=1;
-      }
-    break;
-    /*
-     * trying to go NORTH EAST
-     */
-    case 2: if (CURRENT_AREA[((*y)-1)*CURRENT_AREA_W+(*x)+1].mesh)
-      {
-	(*y)--;
-	(*x)++;
-	moved=1;
-      }
-    break;
-    /*
-     * trying to go EAST
-     */
-    case 3: if (CURRENT_AREA[(*y)*CURRENT_AREA_W+(*x)+1].mesh)
-      {
-	(*x)++;
-	moved=1;
-      }
-    break;
-    /*
-     * trying to go SOUTH EAST
-     */
-    case 4: if (CURRENT_AREA[((*y)+1)*CURRENT_AREA_W+(*x)+1].mesh)
-      {
-	(*x)++;
-	(*y)++;
-	moved=1;
-      }
-    break;
-    /*
-     * trying to go SOUTH
-     */
-    case 5: if (CURRENT_AREA[((*y)+1)*CURRENT_AREA_W+(*x)].mesh)
-      {
-	(*y)++;
-	moved=1;
-      }
-    break;
-    /*
-     * trying to go SOUTH WEST
-     */
-    case 6: if (CURRENT_AREA[((*y)+1)*CURRENT_AREA_W+(*x)-1].mesh)
-      {
-	(*y)++;
-	(*x)--;
-	moved=1;
-      }
-    break;
-    /*
-     * trying to go WEST
-     */
-    case 7: if (CURRENT_AREA[(*y)*CURRENT_AREA_W+(*x)-1].mesh)
-      {
-	(*x)--;
-	moved=1;
-      }
-    break;
-    /*
-     * trying to go NORTH WEST
-     */
-    case 8: if (CURRENT_AREA[((*y)-1)*CURRENT_AREA_W+(*x)-1].mesh)
-      {
-	(*x)--;
-	(*y)--;
-	moved=1;
-      }
+    case 1:
+      if (CURRENT_AREA[((*y) - 1) * CURRENT_AREA_W + (*x)].mesh)
+	{
+	  (*y)--;
+	  moved = 1;
+	}
+      break;
+      /*
+       * trying to go NORTH EAST
+       */
+    case 2:
+      if (CURRENT_AREA[((*y) - 1) * CURRENT_AREA_W + (*x) + 1].mesh)
+	{
+	  (*y)--;
+	  (*x)++;
+	  moved = 1;
+	}
+      break;
+      /*
+       * trying to go EAST
+       */
+    case 3:
+      if (CURRENT_AREA[(*y) * CURRENT_AREA_W + (*x) + 1].mesh)
+	{
+	  (*x)++;
+	  moved = 1;
+	}
+      break;
+      /*
+       * trying to go SOUTH EAST
+       */
+    case 4:
+      if (CURRENT_AREA[((*y) + 1) * CURRENT_AREA_W + (*x) + 1].mesh)
+	{
+	  (*x)++;
+	  (*y)++;
+	  moved = 1;
+	}
+      break;
+      /*
+       * trying to go SOUTH
+       */
+    case 5:
+      if (CURRENT_AREA[((*y) + 1) * CURRENT_AREA_W + (*x)].mesh)
+	{
+	  (*y)++;
+	  moved = 1;
+	}
+      break;
+      /*
+       * trying to go SOUTH WEST
+       */
+    case 6:
+      if (CURRENT_AREA[((*y) + 1) * CURRENT_AREA_W + (*x) - 1].mesh)
+	{
+	  (*y)++;
+	  (*x)--;
+	  moved = 1;
+	}
+      break;
+      /*
+       * trying to go WEST
+       */
+    case 7:
+      if (CURRENT_AREA[(*y) * CURRENT_AREA_W + (*x) - 1].mesh)
+	{
+	  (*x)--;
+	  moved = 1;
+	}
+      break;
+      /*
+       * trying to go NORTH WEST
+       */
+    case 8:
+      if (CURRENT_AREA[((*y) - 1) * CURRENT_AREA_W + (*x) - 1].mesh)
+	{
+	  (*x)--;
+	  (*y)--;
+	  moved = 1;
+	}
     }
   return moved;
 }
@@ -193,117 +202,118 @@ static int move_if_free (int *x, int *y, int dir)
  * in fact it interprets the key_state value , calculates the
  * direction to use and then calls move_if_free
  */
-static void move_cursor (int indice)
+static void
+move_cursor (int indice)
 {
-  int dir=0,up,down,right,left,horiz=0,vert=0,moved=0,team;
+  int dir = 0, up, down, right, left, horiz = 0, vert = 0, moved = 0, team;
   char key_state;
   MESH *mesh;
 
   /*
    * we get the team associated to the cursor
    */
-  team=CURRENT_CURSOR[indice].team;
+  team = CURRENT_CURSOR[indice].team;
   /*
    * we get the mesh item associated to the current position of the cursor
    */
-  mesh=CURRENT_AREA [CURRENT_CURSOR[indice].y*CURRENT_AREA_W
-		    +CURRENT_CURSOR[indice].x].mesh;
+  mesh = CURRENT_AREA[CURRENT_CURSOR[indice].y * CURRENT_AREA_W
+		      + CURRENT_CURSOR[indice].x].mesh;
   /*
    * we tell the mesh that the info won't be up to date anymore concerning
    * this position
    */
-  mesh->info[team].update.time=-1;
+  mesh->info[team].update.time = -1;
 
   /*
    * the key_state value gives the state of all pressed/unpressed keys
    */
-  key_state=CURRENT_CURSOR[indice].key_state;
+  key_state = CURRENT_CURSOR[indice].key_state;
 
   /*
    * we interpret the content of the key_state value with binary masks
    */
-  up=key_state&CURSOR_KEY_UP;
-  right=key_state&CURSOR_KEY_RIGHT;
-  down=key_state&CURSOR_KEY_DOWN;
-  left=key_state&CURSOR_KEY_LEFT;
+  up = key_state & CURSOR_KEY_UP;
+  right = key_state & CURSOR_KEY_RIGHT;
+  down = key_state & CURSOR_KEY_DOWN;
+  left = key_state & CURSOR_KEY_LEFT;
 
   /*
    * if both left and right keys are pressed, no horizontal move!
    */
-  if ((right&&left) || ((!right)&&(!left)))
-    horiz=0;
+  if ((right && left) || ((!right) && (!left)))
+    horiz = 0;
   /*
    * if right key is pressed but not left key, let's go right
    */
-  if (right&&(!left))
-    horiz=1;
+  if (right && (!left))
+    horiz = 1;
   /*
    * if left key is pressed but not right key, let's go left
    */
-  if ((!right)&&left)
-    horiz=-1;
+  if ((!right) && left)
+    horiz = -1;
 
   /*
    * if both up and down keys are pressed, no verical move!
    */
-  if ((up&&down) || ((!up)&&(!down)))
-    vert=0;
+  if ((up && down) || ((!up) && (!down)))
+    vert = 0;
   /*
    * if up key is pressed but not down key, let's go up
    */
-  if (up&&(!down))
-    vert=-1;
+  if (up && (!down))
+    vert = -1;
   /*
    * if down key is pressed but not up key, let's go down
    */
-  if ((!up)&&down)
-    vert=1;
+  if ((!up) && down)
+    vert = 1;
 
   /*
    * the cursor does not move at all
    */
-  if (horiz==0 && vert==0)
-    dir=0;
+  if (horiz == 0 && vert == 0)
+    dir = 0;
   /*
    * the cursor heads NORTH
    */
-  if (horiz==0 && vert==-1)
-    dir=1;
+  if (horiz == 0 && vert == -1)
+    dir = 1;
   /*
    * the cursor heads NORTH EAST
    */
-  if (horiz==1 && vert==-1)
-    dir=2;
+  if (horiz == 1 && vert == -1)
+    dir = 2;
   /*
    * the cursor heads EAST
    */
-  if (horiz==1 && vert==0)
-    dir=3;
+  if (horiz == 1 && vert == 0)
+    dir = 3;
   /*
    * the cursor heads SOUTH EAST
    */
-  if (horiz==1 && vert==1)
-    dir=4;
+  if (horiz == 1 && vert == 1)
+    dir = 4;
   /*
    * the cursor heads SOUTH
    */
-  if (horiz==0 && vert==1)
-    dir=5;
+  if (horiz == 0 && vert == 1)
+    dir = 5;
   /*
    * the cursor heads SOUTH WEST
    */
-  if (horiz==-1 && vert==1)
-    dir=6;
+  if (horiz == -1 && vert == 1)
+    dir = 6;
   /*
    * the cursor heads WEST
    */
-  if (horiz==-1 && vert==0)
-    dir=7;
+  if (horiz == -1 && vert == 0)
+    dir = 7;
   /*
    * the cursor heads NORTH WEST
    */
-  if (horiz==-1 && vert==-1)
-    dir=8;
+  if (horiz == -1 && vert == -1)
+    dir = 8;
 
   /*
    * if no direction has been found, we do nothing
@@ -313,69 +323,66 @@ static void move_cursor (int indice)
       /*
        * we first try to move in the direction we have calculated
        */
-      moved=move_if_free (&(CURRENT_CURSOR[indice].x),
-			  &(CURRENT_CURSOR[indice].y),
-			  dir);
+      moved = move_if_free (&(CURRENT_CURSOR[indice].x),
+			    &(CURRENT_CURSOR[indice].y), dir);
       /*
        * if it did not work, we try another direction
        * for instance if the direction was NORTH WEST we try WEST
        */
       if (!moved)
-        moved=move_if_free (&(CURRENT_CURSOR[indice].x),
-                            &(CURRENT_CURSOR[indice].y),
-                            dir-1);
+	moved = move_if_free (&(CURRENT_CURSOR[indice].x),
+			      &(CURRENT_CURSOR[indice].y), dir - 1);
       /*
        * if it did not work, we try another direction
        * for instance if the direction was NORTH WEST we try NORTH
        */
       if (!moved)
-        moved=move_if_free (&(CURRENT_CURSOR[indice].x),
-                            &(CURRENT_CURSOR[indice].y),
-                            dir+1);
+	moved = move_if_free (&(CURRENT_CURSOR[indice].x),
+			      &(CURRENT_CURSOR[indice].y), dir + 1);
       /*
        * The following code allows the cursor to really "slip" on walls.
        * Not very elegant, but it works 8-)
        */
       if (!moved)
 	{
-	  int xa1,ya1;
-	  int xb1,yb1;
-	  int xa2,ya2;
-	  int xb2,yb2;
-	  int i=0;
+	  int xa1, ya1;
+	  int xb1, yb1;
+	  int xa2, ya2;
+	  int xb2, yb2;
+	  int i = 0;
 
-	  xa1=xb1=CURRENT_CURSOR[indice].x;
-	  ya1=yb1=CURRENT_CURSOR[indice].y;
-	  
-	  while (!moved && i<LW_MOVE_SIDE_LIMIT)
+	  xa1 = xb1 = CURRENT_CURSOR[indice].x;
+	  ya1 = yb1 = CURRENT_CURSOR[indice].y;
+
+	  while (!moved && i < LW_MOVE_SIDE_LIMIT)
 	    {
-	      if (move_if_free(&xa1,&ya1,dir-2))
+	      if (move_if_free (&xa1, &ya1, dir - 2))
 		{
-		  xa2=xa1;
-		  ya2=ya1;
-		  if (move_if_free(&xa2,&ya2,dir-1))
+		  xa2 = xa1;
+		  ya2 = ya1;
+		  if (move_if_free (&xa2, &ya2, dir - 1))
 		    {
 		      /*
 		       * Normally moved should be true after this
 		       */
-		      moved=move_if_free(&(CURRENT_CURSOR[indice].x),
-					 &(CURRENT_CURSOR[indice].y),
-					 dir-2);
+		      moved = move_if_free (&(CURRENT_CURSOR[indice].x),
+					    &(CURRENT_CURSOR[indice].y),
+					    dir - 2);
 		    }
 		}
 
-	      if (move_if_free(&xb1,&yb1,dir+2))
+	      if (move_if_free (&xb1, &yb1, dir + 2))
 		{
-		  xb2=xb1;
-		  yb2=yb1;
-		  if (move_if_free(&xb2,&yb2,dir+1))
+		  xb2 = xb1;
+		  yb2 = yb1;
+		  if (move_if_free (&xb2, &yb2, dir + 1))
 		    {
 		      /*
 		       * Normally moved should be true after this
 		       */
-		      moved=move_if_free(&(CURRENT_CURSOR[indice].x),
-					 &(CURRENT_CURSOR[indice].y),
-					 dir+2);
+		      moved = move_if_free (&(CURRENT_CURSOR[indice].x),
+					    &(CURRENT_CURSOR[indice].y),
+					    dir + 2);
 		    }
 		}
 
@@ -394,7 +401,7 @@ static void move_cursor (int indice)
    *   this avoids cyclic behaviors and some "lost" fighters which
    *   might otherwise start looping in a corner of the map
    */
-  if (moved || !(GLOBAL_CLOCK%(NB_DIRS+1)))
+  if (moved || !(GLOBAL_CLOCK % (NB_DIRS + 1)))
     {
       CURRENT_CURSOR[indice].val--;
     }
@@ -402,15 +409,15 @@ static void move_cursor (int indice)
   /*
    * we retrieve the new mesh item associated to the new position
    */
-  mesh=CURRENT_AREA [CURRENT_CURSOR[indice].y*CURRENT_AREA_W
-		    +CURRENT_CURSOR[indice].x].mesh;
+  mesh = CURRENT_AREA[CURRENT_CURSOR[indice].y * CURRENT_AREA_W
+		      + CURRENT_CURSOR[indice].x].mesh;
   /*
    * we tell the mesh where the cursor is
    * this information is redundant but it avoids complex things such as 
    * my_struct->....->...   ...->...->my_attribute;
    */
-  mesh->info[team].update.cursor.x=CURRENT_CURSOR[indice].x;
-  mesh->info[team].update.cursor.y=CURRENT_CURSOR[indice].y;
+  mesh->info[team].update.cursor.x = CURRENT_CURSOR[indice].x;
+  mesh->info[team].update.cursor.y = CURRENT_CURSOR[indice].y;
 }
 
 /*------------------------------------------------------------------*/
@@ -418,7 +425,8 @@ static void move_cursor (int indice)
  * updates the key_state value for a local player, ie polls the keys
  * it might also poll the joystick but this is transparent
  */
-static void update_key_local_cursor (int indice)
+static void
+update_key_local_cursor (int indice)
 {
   /*
    * the following code is pretty much the same for each key.
@@ -427,26 +435,26 @@ static void update_key_local_cursor (int indice)
    * is in a "pressed" state
    */
   CURRENT_CURSOR[indice].key_state
-    =is_touched_key (CONFIG_KEY_UP[indice]) ? CURSOR_KEY_UP : 0;
+    = is_touched_key (CONFIG_KEY_UP[indice]) ? CURSOR_KEY_UP : 0;
   CURRENT_CURSOR[indice].key_state
-    +=is_touched_key (CONFIG_KEY_RIGHT[indice]) ? CURSOR_KEY_RIGHT : 0;
+    += is_touched_key (CONFIG_KEY_RIGHT[indice]) ? CURSOR_KEY_RIGHT : 0;
   CURRENT_CURSOR[indice].key_state
-    +=is_touched_key (CONFIG_KEY_DOWN[indice]) ? CURSOR_KEY_DOWN : 0;
+    += is_touched_key (CONFIG_KEY_DOWN[indice]) ? CURSOR_KEY_DOWN : 0;
   CURRENT_CURSOR[indice].key_state
-    +=is_touched_key (CONFIG_KEY_LEFT[indice]) ? CURSOR_KEY_LEFT : 0;
+    += is_touched_key (CONFIG_KEY_LEFT[indice]) ? CURSOR_KEY_LEFT : 0;
 }
 
 /*------------------------------------------------------------------*/
 /*
  * updates the key_state for a cursor which is AI driven
  */
-static void update_key_cpu_cursor (int indice)
+static void
+update_key_cpu_cursor (int indice)
 {
   /*
    * get_computer_next_move is the main AI function
    */
-  CURRENT_CURSOR[indice].key_state
-    =get_computer_next_move(indice);
+  CURRENT_CURSOR[indice].key_state = get_computer_next_move (indice);
 }
 
 /*------------------------------------------------------------------*/
@@ -454,30 +462,31 @@ static void update_key_cpu_cursor (int indice)
  * moves all the cursors, (logical, eh?)
  * the kind of function one might wish to use in the main game loop
  */
-void move_all_cursors (void)
+void
+move_all_cursors (void)
 {
-  int i,j;
+  int i, j;
   int checksum;
 
   /*
    * polls the module which wraps mouse moves to virtual keys
    */
-  lw_mouse_update_control();
+  lw_mouse_update_control ();
   /*
    * polls the joystick
    */
-  my_poll_joystick();
+  my_poll_joystick ();
   /*
    * one might wish to poll network stuff here but I'm not sure it's
    * the right place because of performance issues
    */
 
-  for (j=0; j<=LW_CONFIG_CURRENT_RULES.cursor_increase_speed; ++j)
+  for (j = 0; j <= LW_CONFIG_CURRENT_RULES.cursor_increase_speed; ++j)
     {
       /*
        * loop for all the teams, the cursor of which is active
        */
-      for (i=0;i<NB_TEAMS;++i)
+      for (i = 0; i < NB_TEAMS; ++i)
 	{
 	  if (CURRENT_CURSOR[i].active)
 	    {
@@ -486,20 +495,20 @@ void move_all_cursors (void)
 	       */
 	      if (!CURRENT_CURSOR[i].from_network)
 		{
-		  if (CURRENT_CURSOR[i].control_type == 
+		  if (CURRENT_CURSOR[i].control_type ==
 		      CONFIG_CONTROL_TYPE_CPU)
 		    {
 		      /*
 		       * the cursor is controlled by the computer
 		       */
-		      update_key_cpu_cursor(i);
+		      update_key_cpu_cursor (i);
 		    }
 		  else
 		    {
 		      /*
 		       * the cursor is controlled by a human local player
 		       */
-		      update_key_local_cursor(i);		
+		      update_key_local_cursor (i);
 		    }
 		}
 	    }
@@ -509,19 +518,19 @@ void move_all_cursors (void)
        */
       if (LW_NETWORK_ON)
 	{
-	  checksum=lw_checksum_calc(CURRENT_ARMY,CURRENT_ARMY_SIZE);
+	  checksum = lw_checksum_calc (CURRENT_ARMY, CURRENT_ARMY_SIZE);
 
 	  /*
 	   * This call will automatically overwrite the key states
 	   * with those received from the network
 	   */
-	  if (!lw_keyexch_flush(CURRENT_CURSOR, checksum))
+	  if (!lw_keyexch_flush (CURRENT_CURSOR, checksum))
 	    {
-	      LW_NETWORK_ERROR_DETECTED=1;
+	      LW_NETWORK_ERROR_DETECTED = 1;
 	    }
 	}
 
-      for (i=0;i<NB_TEAMS;++i)
+      for (i = 0; i < NB_TEAMS; ++i)
 	{
 	  if (CURRENT_CURSOR[i].active)
 	    {
@@ -530,7 +539,3 @@ void move_all_cursors (void)
 	}
     }
 }
-
-
-
-
