@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -62,76 +62,76 @@
 /* variables globales                                               */
 /*==================================================================*/
 
-int MUSIC_VOLUME=0;
+int MUSIC_VOLUME = 0;
 
-static int MUSIC_VOLUME_VALUES[17]=
-  { 0,
-    16,32,48,64,
-    80,96,112,128,
-    144,160,176,192,
-    208,224,240,255};
+static int MUSIC_VOLUME_VALUES[17] = { 0,
+  16, 32, 48, 64,
+  80, 96, 112, 128,
+  144, 160, 176, 192,
+  208, 224, 240, 255
+};
 
 /*==================================================================*/
 /* functions                                                        */
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-int start_music (void)
+int
+start_music (void)
 {
   static int last_volume = -1;
   static int last_file = -1;
-  int result=1;
+  int result = 1;
   int i;
 
   /*
    * we pick up a random music, letting the user choose the music
    * would imply work on the GUI, which is very time consuming 8-(
    */
-  if (STARTUP_MUSIC_STATE && MIDI_MUSIC_NUMBER>=0)
-    { 
+  if (STARTUP_MUSIC_STATE && MIDI_MUSIC_NUMBER >= 0)
+    {
       /*
        * we try and pick up a music that is different from
        * the last music played
        */
-      if (MIDI_MUSIC_NUMBER>=2) 
-	{     
+      if (MIDI_MUSIC_NUMBER >= 2)
+	{
 	  do
 	    {
-	      i = rand() % MIDI_MUSIC_NUMBER;
+	      i = random () % MIDI_MUSIC_NUMBER;
 	    }
-	  while (i==last_file);
+	  while (i == last_file);
 	}
       else
 	{
 	  /*
 	   * we have only 1 midi file loaded...
 	   */
-	  i=0;
-	}   
+	  i = 0;
+	}
       last_file = i;
-      
+
       if (CONFIG_MUSIC_VOLUME != last_volume)
 	{
-	  set_volume(-1,MUSIC_VOLUME_VALUES[CONFIG_MUSIC_VOLUME]);
-	  last_volume=CONFIG_MUSIC_VOLUME;
+	  set_volume (-1, MUSIC_VOLUME_VALUES[CONFIG_MUSIC_VOLUME]);
+	  last_volume = CONFIG_MUSIC_VOLUME;
 	}
 
-      result = play_midi(MIDI_MUSIC[i],TRUE);
+      result = play_midi (MIDI_MUSIC[i], TRUE);
     }
 
   return result;
 }
 
 /*------------------------------------------------------------------*/
-void stop_music (void)
+void
+stop_music (void)
 {
   if (STARTUP_MUSIC_STATE)
     {
       /*
        * Calling play_midi with a NULL arg ends the midi output
        */
-      play_midi(NULL,FALSE);
+      play_midi (NULL, FALSE);
     }
 }
-
-
