@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -59,6 +59,7 @@
 #include "netconf.h"
 #include "sock2gen.h"
 #include "log.h"
+#include "macro.h"
 
 /*==================================================================*/
 /* constants                                                        */
@@ -107,52 +108,54 @@ log_println_int(config-> ## VAL);
 /*
  * Sends a config over the network
  */
-int lw_netconf_send(int sock, LW_NETCONF *config)
+int
+lw_netconf_send (int sock, LW_NETCONF * config)
 {
-  int result=0;
+  int result = 0;
   char buffer[LW_SOCK_MESSAGE_SIZE];
 
-  sprintf(buffer,"%d",
-	  config->cursor_increase_speed);
-  if (lw_sock_send_str(sock,buffer))
+  LW_MACRO_SPRINTF1 (buffer, "%d", config->cursor_increase_speed);
+  if (lw_sock_send_str (sock, buffer))
     {
-      sprintf(buffer,"%d",
-	      config->fighter_attack);
-      if (lw_sock_send_str(sock,buffer))
+      LW_MACRO_SPRINTF1 (buffer, "%d", config->fighter_attack);
+      if (lw_sock_send_str (sock, buffer))
 	{
-	  sprintf(buffer,"%d",
-		  config->fighter_defense);
-	  if (lw_sock_send_str(sock,buffer))
+	  LW_MACRO_SPRINTF1 (buffer, "%d", config->fighter_defense);
+	  if (lw_sock_send_str (sock, buffer))
 	    {
-	      sprintf(buffer,"%d",
-		      config->fighter_new_health);
-	      if (lw_sock_send_str(sock,buffer))
+	      LW_MACRO_SPRINTF1 (buffer, "%d", config->fighter_new_health);
+	      if (lw_sock_send_str (sock, buffer))
 		{
-		  sprintf(buffer,"%d",
-			  config->number_influence);
-		  if (lw_sock_send_str(sock,buffer))
+		  LW_MACRO_SPRINTF1 (buffer, "%d", config->number_influence);
+		  if (lw_sock_send_str (sock, buffer))
 		    {
-		      sprintf(buffer,"%d",
-			      config->fighter_number);
-		      if (lw_sock_send_str(sock,buffer))
+		      LW_MACRO_SPRINTF1 (buffer, "%d",
+					 config->fighter_number);
+		      if (lw_sock_send_str (sock, buffer))
 			{
-			  sprintf(buffer,"%d",
-				  config->game_time);
-			  if (lw_sock_send_str(sock,buffer))
+			  LW_MACRO_SPRINTF1 (buffer, "%d", config->game_time);
+			  if (lw_sock_send_str (sock, buffer))
 			    {
-			      sprintf(buffer,"%d",
-				      config->cpu_advantage);
-			      if (lw_sock_send_str(sock,buffer))
+			      LW_MACRO_SPRINTF1 (buffer, "%d",
+						 config->cpu_advantage);
+			      if (lw_sock_send_str (sock, buffer))
 				{
-				  sprintf(buffer,"%d",
-					  config->asm_algorithm);
-				  if (lw_sock_send_str(sock,buffer))
+				  LW_MACRO_SPRINTF1 (buffer, "%d",
+						     config->cpu_vs_human);
+				  if (lw_sock_send_str (sock, buffer))
 				    {
-				      sprintf(buffer,"%d",
-					      config->min_map_res);
-				      if (lw_sock_send_str(sock,buffer))
+				      LW_MACRO_SPRINTF1 (buffer, "%d",
+							 config->
+							 asm_algorithm);
+				      if (lw_sock_send_str (sock, buffer))
 					{
-					  result=1;
+					  LW_MACRO_SPRINTF1 (buffer, "%d",
+							     config->
+							     min_map_res);
+					  if (lw_sock_send_str (sock, buffer))
+					    {
+					      result = 1;
+					    }
 					}
 				    }
 				}
@@ -163,7 +166,7 @@ int lw_netconf_send(int sock, LW_NETCONF *config)
 	    }
 	}
     }
-    
+
   return result;
 }
 
@@ -171,45 +174,52 @@ int lw_netconf_send(int sock, LW_NETCONF *config)
 /*
  * Receives a config from the network
  */
-int lw_netconf_recv(int sock, LW_NETCONF *config)
+int
+lw_netconf_recv (int sock, LW_NETCONF * config)
 {
-  int result=0;
+  int result = 0;
   char buffer[LW_SOCK_MESSAGE_SIZE];
 
-  memset(config,0,sizeof(LW_NETCONF));
+  memset (config, 0, sizeof (LW_NETCONF));
 
-  if (lw_sock_recv_str(sock,buffer))
+  if (lw_sock_recv_str (sock, buffer))
     {
-      config->cursor_increase_speed=atoi(buffer);
-      if (lw_sock_recv_str(sock,buffer))
+      config->cursor_increase_speed = atoi (buffer);
+      if (lw_sock_recv_str (sock, buffer))
 	{
-	  config->fighter_attack=atoi(buffer);
-	  if (lw_sock_recv_str(sock,buffer))
+	  config->fighter_attack = atoi (buffer);
+	  if (lw_sock_recv_str (sock, buffer))
 	    {
-	      config->fighter_defense=atoi(buffer);
-	      if (lw_sock_recv_str(sock,buffer))
+	      config->fighter_defense = atoi (buffer);
+	      if (lw_sock_recv_str (sock, buffer))
 		{
-		  config->fighter_new_health=atoi(buffer);
-		  if (lw_sock_recv_str(sock,buffer))
+		  config->fighter_new_health = atoi (buffer);
+		  if (lw_sock_recv_str (sock, buffer))
 		    {
-		      config->number_influence=atoi(buffer);
-		      if (lw_sock_recv_str(sock,buffer))
+		      config->number_influence = atoi (buffer);
+		      if (lw_sock_recv_str (sock, buffer))
 			{
-			  config->fighter_number=atoi(buffer);
-			  if (lw_sock_recv_str(sock,buffer))
+			  config->fighter_number = atoi (buffer);
+			  if (lw_sock_recv_str (sock, buffer))
 			    {
-			      config->game_time=atoi(buffer);
-			      if (lw_sock_recv_str(sock,buffer))
+			      config->game_time = atoi (buffer);
+			      if (lw_sock_recv_str (sock, buffer))
 				{
-				  config->cpu_advantage=atoi(buffer);
-				  if (lw_sock_recv_str(sock,buffer))
+				  config->cpu_advantage = atoi (buffer);
+				  if (lw_sock_recv_str (sock, buffer))
 				    {
-				      config->asm_algorithm=atoi(buffer);
-				      if (lw_sock_recv_str(sock,buffer))
+				      config->cpu_vs_human = atoi (buffer);
+				      if (lw_sock_recv_str (sock, buffer))
 					{
-					  config->min_map_res=atoi(buffer);
-					  
-					  result=1;
+					  config->asm_algorithm =
+					    atoi (buffer);
+					  if (lw_sock_recv_str (sock, buffer))
+					    {
+					      config->min_map_res =
+						atoi (buffer);
+
+					      result = 1;
+					    }
 					}
 				    }
 				}
@@ -228,20 +238,22 @@ int lw_netconf_recv(int sock, LW_NETCONF *config)
 /*
  * Checks if all the values are within an acceptable range
  */
-int lw_netconf_check(LW_NETCONF *config)
+int
+lw_netconf_check (LW_NETCONF * config)
 {
-  int result=1;
+  int result = 1;
 
-  LW_NETCONF_CHECK_RANGE(cursor_increase_speed,2);
-  LW_NETCONF_CHECK_RANGE(fighter_attack,16);
-  LW_NETCONF_CHECK_RANGE(fighter_defense,16);
-  LW_NETCONF_CHECK_RANGE(fighter_new_health,16);
-  LW_NETCONF_CHECK_RANGE(number_influence,16);
-  LW_NETCONF_CHECK_RANGE(fighter_number,32);
-  LW_NETCONF_CHECK_RANGE(game_time,16);
-  LW_NETCONF_CHECK_RANGE(cpu_advantage,4);
-  LW_NETCONF_CHECK_RANGE(asm_algorithm,1);
-  LW_NETCONF_CHECK_RANGE(min_map_res,8);
+  LW_NETCONF_CHECK_RANGE (cursor_increase_speed, 2);
+  LW_NETCONF_CHECK_RANGE (fighter_attack, 16);
+  LW_NETCONF_CHECK_RANGE (fighter_defense, 16);
+  LW_NETCONF_CHECK_RANGE (fighter_new_health, 16);
+  LW_NETCONF_CHECK_RANGE (number_influence, 16);
+  LW_NETCONF_CHECK_RANGE (fighter_number, 32);
+  LW_NETCONF_CHECK_RANGE (game_time, 16);
+  LW_NETCONF_CHECK_RANGE (cpu_advantage, 4);
+  LW_NETCONF_CHECK_RANGE (cpu_vs_human, 2);
+  LW_NETCONF_CHECK_RANGE (asm_algorithm, 1);
+  LW_NETCONF_CHECK_RANGE (min_map_res, 8);
 
   return result;
 }
@@ -250,16 +262,18 @@ int lw_netconf_check(LW_NETCONF *config)
 /*
  * Prints the contents of a NETCONF object
  */
-void lw_netconf_print(LW_NETCONF *config)
+void
+lw_netconf_print (LW_NETCONF * config)
 {
-  LW_NETCONF_PRINT_VALUE(cursor_increase_speed);
-  LW_NETCONF_PRINT_VALUE(fighter_attack);
-  LW_NETCONF_PRINT_VALUE(fighter_defense);
-  LW_NETCONF_PRINT_VALUE(fighter_new_health);
-  LW_NETCONF_PRINT_VALUE(number_influence);
-  LW_NETCONF_PRINT_VALUE(fighter_number);
-  LW_NETCONF_PRINT_VALUE(game_time);
-  LW_NETCONF_PRINT_VALUE(cpu_advantage);
-  LW_NETCONF_PRINT_VALUE(asm_algorithm);
-  LW_NETCONF_PRINT_VALUE(min_map_res);
+  LW_NETCONF_PRINT_VALUE (cursor_increase_speed);
+  LW_NETCONF_PRINT_VALUE (fighter_attack);
+  LW_NETCONF_PRINT_VALUE (fighter_defense);
+  LW_NETCONF_PRINT_VALUE (fighter_new_health);
+  LW_NETCONF_PRINT_VALUE (number_influence);
+  LW_NETCONF_PRINT_VALUE (fighter_number);
+  LW_NETCONF_PRINT_VALUE (game_time);
+  LW_NETCONF_PRINT_VALUE (cpu_advantage);
+  LW_NETCONF_PRINT_VALUE (cpu_vs_human);
+  LW_NETCONF_PRINT_VALUE (asm_algorithm);
+  LW_NETCONF_PRINT_VALUE (min_map_res);
 }
