@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -53,7 +53,6 @@
 /*==================================================================*/
 
 #include <stdlib.h>
-#include <malloc.h>
 #include <string.h>
 #include <ctype.h>
 
@@ -81,10 +80,10 @@ typedef unsigned char LW_NETKEY_SERIALIZED[LW_NETKEY_SERIALIZED_SIZE];
 /* static functions declaration                                     */
 /*==================================================================*/
 
-static char int_to_ascii_hexa(int src);
-static int ascii_hexa_to_int(char src);
-static void encode(LW_NETKEY_SERIALIZED dst, LW_NETKEY *src);
-static void decode(LW_NETKEY *dst, LW_NETKEY_SERIALIZED src);
+static char int_to_ascii_hexa (int src);
+static int ascii_hexa_to_int (char src);
+static void encode (LW_NETKEY_SERIALIZED dst, LW_NETKEY * src);
+static void decode (LW_NETKEY * dst, LW_NETKEY_SERIALIZED src);
 
 /*==================================================================*/
 /* functions                                                        */
@@ -94,35 +93,37 @@ static void decode(LW_NETKEY *dst, LW_NETKEY_SERIALIZED src);
 /*
  * Creates a blank netkey struct
  */
-void lw_netkey_reset(LW_NETKEY *netkey)
+void
+lw_netkey_reset (LW_NETKEY * netkey)
 {
   int i;
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
-      netkey->key_states[i]=0;
+      netkey->key_states[i] = 0;
     }
 
-  netkey->cmd=LW_NETKEY_CMD_NONE;
-  netkey->arg=0;
+  netkey->cmd = LW_NETKEY_CMD_NONE;
+  netkey->arg = 0;
 }
 
 /*------------------------------------------------------------------*/
 /*
  * Transforms an integer into a readable hexadecimal ascii character
  */
-static char int_to_ascii_hexa(int src)
+static char
+int_to_ascii_hexa (int src)
 {
   char dst;
 
-  dst='0';
-  if (src>=1 && src<=9)
+  dst = '0';
+  if (src >= 1 && src <= 9)
     {
-      dst='0'+src;
+      dst = '0' + src;
     }
-  if (src>=10 && src<=15)
+  if (src >= 10 && src <= 15)
     {
-      dst='A'-10+src;
+      dst = 'A' - 10 + src;
     }
 
   return dst;
@@ -132,18 +133,19 @@ static char int_to_ascii_hexa(int src)
 /*
  * Transforms a readable hexadecimal ascii character into an integer
  */
-static int ascii_hexa_to_int(char src)
+static int
+ascii_hexa_to_int (char src)
 {
   int dst;
 
-  dst=0;
-  if (src>='0' && src<='9')
+  dst = 0;
+  if (src >= '0' && src <= '9')
     {
-      dst=src-'0';
+      dst = src - '0';
     }
-  if (src>='A' && src<='F')
+  if (src >= 'A' && src <= 'F')
     {
-      dst=src-'A'+10;
+      dst = src - 'A' + 10;
     }
 
   return dst;
@@ -154,36 +156,37 @@ static int ascii_hexa_to_int(char src)
  * Serializes a LW_NETKEY struct to a buffer which is sendable over
  * the network.
  */
-static void encode(LW_NETKEY_SERIALIZED dst, LW_NETKEY *src)
+static void
+encode (LW_NETKEY_SERIALIZED dst, LW_NETKEY * src)
 {
   int i;
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
       /*
        * we translate each key press (stored as a logical or between
        * 1,2,4 and 8) into a readable hexadecimal character. This
        * makes debugging easier.
        */
-      dst[i]=int_to_ascii_hexa(src->key_states[i]);
+      dst[i] = int_to_ascii_hexa (src->key_states[i]);
     }
 
   /*
    * We store the command as is since it's already a character
    */
-  dst[NB_TEAMS]=src->cmd;
+  dst[NB_TEAMS] = src->cmd;
   /*
    * We transform the argument since we assume it's a numeric arg
    */
-  dst[NB_TEAMS+1]=int_to_ascii_hexa(src->arg);
+  dst[NB_TEAMS + 1] = int_to_ascii_hexa (src->arg);
 
   /*
    * Now we serialize the "map checksum"
    */
-  dst[NB_TEAMS+2+0]=(src->checksum) & 0xFF;
-  dst[NB_TEAMS+2+1]=(src->checksum>>8) & 0xFF;
-  dst[NB_TEAMS+2+2]=(src->checksum>>16) & 0xFF;
-  dst[NB_TEAMS+2+3]=(src->checksum>>24) & 0xFF;
+  dst[NB_TEAMS + 2 + 0] = (src->checksum) & 0xFF;
+  dst[NB_TEAMS + 2 + 1] = (src->checksum >> 8) & 0xFF;
+  dst[NB_TEAMS + 2 + 2] = (src->checksum >> 16) & 0xFF;
+  dst[NB_TEAMS + 2 + 3] = (src->checksum >> 24) & 0xFF;
 }
 
 /*------------------------------------------------------------------*/
@@ -191,52 +194,53 @@ static void encode(LW_NETKEY_SERIALIZED dst, LW_NETKEY *src)
  * Un-serializes a LW_NETKEY struct from a buffer which has been
  * received from the network.
  */
-static void decode(LW_NETKEY *dst, LW_NETKEY_SERIALIZED src)
+static void
+decode (LW_NETKEY * dst, LW_NETKEY_SERIALIZED src)
 {
   int i;
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
       /*
        * we translate each key press (stored as a logical or between
        * 1,2,4 and 8) from a readable hexadecimal character. This
        * makes debugging easier.
        */
-      dst->key_states[i]=ascii_hexa_to_int(src[i]);
+      dst->key_states[i] = ascii_hexa_to_int (src[i]);
     }
 
   /*
    * We store the command as is since it's already a character
    */
-  dst->cmd=src[NB_TEAMS];
+  dst->cmd = src[NB_TEAMS];
   /*
    * We transform the argument since we assume it's a numeric arg
    */
-  dst->arg=ascii_hexa_to_int(src[NB_TEAMS+1]);
+  dst->arg = ascii_hexa_to_int (src[NB_TEAMS + 1]);
 
   /*
    * Now we serialize the "map checksum"
    */
-  dst->checksum=((unsigned int) src[NB_TEAMS+2+3])<<24
-    | ((unsigned int) src[NB_TEAMS+2+2])<<16
-    | ((unsigned int) src[NB_TEAMS+2+1])<<8
-    | ((unsigned int) src[NB_TEAMS+2+0]);
+  dst->checksum = ((unsigned int) src[NB_TEAMS + 2 + 3]) << 24
+    | ((unsigned int) src[NB_TEAMS + 2 + 2]) << 16
+    | ((unsigned int) src[NB_TEAMS + 2 + 1]) << 8
+    | ((unsigned int) src[NB_TEAMS + 2 + 0]);
 }
 
 /*------------------------------------------------------------------*/
 /*
  * Sends a netkey information over the network
  */
-int lw_netkey_send(int sock,LW_NETKEY *netkey)
+int
+lw_netkey_send (int sock, LW_NETKEY * netkey)
 {
   int result;
   LW_NETKEY_SERIALIZED netkey_serialized;
 
-  encode(netkey_serialized,netkey);
+  encode (netkey_serialized, netkey);
 
-  result=lw_sock_send_buffer(sock,
-			     netkey_serialized,
-			     LW_NETKEY_SERIALIZED_SIZE);
+  result = lw_sock_send_buffer (sock,
+				netkey_serialized, LW_NETKEY_SERIALIZED_SIZE);
 
   return result;
 }
@@ -245,16 +249,16 @@ int lw_netkey_send(int sock,LW_NETKEY *netkey)
 /*
  * Receives a netkey information from the network
  */
-int lw_netkey_recv(int sock,LW_NETKEY *netkey)
+int
+lw_netkey_recv (int sock, LW_NETKEY * netkey)
 {
   int result;
   LW_NETKEY_SERIALIZED netkey_serialized;
 
-  result=lw_sock_recv_buffer(sock,
-			     netkey_serialized,
-			     LW_NETKEY_SERIALIZED_SIZE);
+  result = lw_sock_recv_buffer (sock,
+				netkey_serialized, LW_NETKEY_SERIALIZED_SIZE);
 
-  decode(netkey,netkey_serialized);
+  decode (netkey, netkey_serialized);
 
   return result;
 }
@@ -263,11 +267,12 @@ int lw_netkey_recv(int sock,LW_NETKEY *netkey)
 /*
  * Returns true if at leat "num" keys are available on the socket
  */
-int lw_netkey_peek(int sock,int num)
+int
+lw_netkey_peek (int sock, int num)
 {
   int result;
 
-  result=lw_sock_peek(sock,num*LW_NETKEY_SERIALIZED_SIZE);
+  result = lw_sock_peek (sock, num * LW_NETKEY_SERIALIZED_SIZE);
 
   return result;
 }
