@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -56,7 +56,7 @@
 
 #include <allegro.h>
 
-#include "network.h"	
+#include "network.h"
 #include "config.h"
 
 /*==================================================================*/
@@ -71,10 +71,10 @@
 /* globals                                                          */
 /*==================================================================*/
 
-int LW_NETWORK_ON=0;
+int LW_NETWORK_ON = 0;
 LW_WHO LW_NETWORK_INFO[NB_TEAMS];
-int LW_NETWORK_ERROR_DETECTED=0;
-void *LW_NETWORK_RAW_MAP=NULL;
+int LW_NETWORK_ERROR_DETECTED = 0;
+void *LW_NETWORK_RAW_MAP = NULL;
 
 /*==================================================================*/
 /* static funcs                                                     */
@@ -91,35 +91,36 @@ void *LW_NETWORK_RAW_MAP=NULL;
  * about the sane, it is 1. For radicaly different colors, it is
  * 6. If the colors are the same, it is 0.
  */
-int distance_between_colors(int col1,int col2)
+int
+distance_between_colors (int col1, int col2)
 {
   int dist;
 
-  if (col1<0 || col2<0)
+  if (col1 < 0 || col2 < 0)
     {
       /*
        * Now if one of the member was -1, we
        * consider the colors are "far"
        * from each other.
        */
-      dist=6;
+      dist = 6;
     }
   else
     {
-      dist=abs(col1-col2);
+      dist = abs (col1 - col2);
     }
 
-  if (dist>LW_NETWORK_COLOR_NB)
+  if (dist > LW_NETWORK_COLOR_NB)
     {
       /*
        * Normally we should never get here...
        */
-      dist=LW_NETWORK_COLOR_NB/2;
+      dist = LW_NETWORK_COLOR_NB / 2;
     }
 
-  if (dist>LW_NETWORK_COLOR_NB/2)
+  if (dist > LW_NETWORK_COLOR_NB / 2)
     {
-      dist=LW_NETWORK_COLOR_NB-dist;
+      dist = LW_NETWORK_COLOR_NB - dist;
     }
 
   return dist;
@@ -130,27 +131,27 @@ int distance_between_colors(int col1,int col2)
  * Calculates the "most different color", considering the colors 
  * already chosen in LW_NETWORK_INFO.
  */
-int choose_different_color()
+int
+choose_different_color ()
 {
   int color;
   int closeness[LW_NETWORK_COLOR_NB];
   int closeness_min;
   int dist;
-  int i,j;
+  int i, j;
 
   /*
    * We calculate the "closeness" of each color
    */
-  for (i=0;i<LW_NETWORK_COLOR_NB;++i)
+  for (i = 0; i < LW_NETWORK_COLOR_NB; ++i)
     {
-      closeness[i]=0;
-      for (j=0;j<NB_TEAMS;++j)
+      closeness[i] = 0;
+      for (j = 0; j < NB_TEAMS; ++j)
 	{
 	  if (LW_NETWORK_INFO[j].active)
 	    {
-	      dist=distance_between_colors
-		(LW_NETWORK_INFO[j].color,i);
-	      if (dist>0)
+	      dist = distance_between_colors (LW_NETWORK_INFO[j].color, i);
+	      if (dist > 0)
 		{
 		  if (LW_NETWORK_INFO[j].network)
 		    {
@@ -162,11 +163,11 @@ int choose_different_color()
 		       */
 		      dist++;
 		    }
-		  closeness[i]+=LW_NETWORK_COLOR_DIST_SCALE/(dist*dist);
+		  closeness[i] += LW_NETWORK_COLOR_DIST_SCALE / (dist * dist);
 		}
 	      else
 		{
-		  closeness[i]=LW_NETWORK_COLOR_DIST_MAXINT;
+		  closeness[i] = LW_NETWORK_COLOR_DIST_MAXINT;
 		}
 	    }
 	}
@@ -176,14 +177,14 @@ int choose_different_color()
    * And now we pick up the one that has the less common points
    * with existing colors.
    */
-  closeness_min=LW_NETWORK_COLOR_DIST_MAXINT;
-  color=0;
-  for (i=0;i<LW_NETWORK_COLOR_NB;++i)
+  closeness_min = LW_NETWORK_COLOR_DIST_MAXINT;
+  color = 0;
+  for (i = 0; i < LW_NETWORK_COLOR_NB; ++i)
     {
-      if (closeness[i]<closeness_min)
+      if (closeness[i] < closeness_min)
 	{
-	  color=i;
-	  closeness_min=closeness[i];
+	  color = i;
+	  closeness_min = closeness[i];
 	}
     }
 
@@ -194,11 +195,12 @@ int choose_different_color()
 /*
  * Associates a color to each team 
  */
-void lw_network_attribute_colors()
+void
+lw_network_attribute_colors ()
 {
-  int i,color;
+  int i, color;
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
       if (LW_NETWORK_INFO[i].active)
 	{
@@ -208,37 +210,21 @@ void lw_network_attribute_colors()
 	       * -1 is a temporary value which will be overwritten
 	       * by the _real_ value later
 	       */
-	      LW_NETWORK_INFO[i].color=-1;
+	      LW_NETWORK_INFO[i].color = -1;
 	    }
 	  else
 	    {
-	      LW_NETWORK_INFO[i].color=CONFIG_TEAM_COLOR[i];
+	      LW_NETWORK_INFO[i].color = CONFIG_TEAM_COLOR[i];
 	    }
 	}
     }
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
       if (LW_NETWORK_INFO[i].active && LW_NETWORK_INFO[i].network)
 	{
-	  /*
-	  duplicate=1;
-	  while (duplicate)
-	    {
-	      color=(rand()%12);
-	      duplicate=0;
-	      for (j=0;j<NB_TEAMS;++j)
-		{
-		  if (LW_NETWORK_INFO[j].active && 
-		      LW_NETWORK_INFO[j].color==color)
-		    {
-		      duplicate=1;
-		    }
-		}
-	    }
-	  */
-	  color=choose_different_color();
-	  LW_NETWORK_INFO[i].color=color;
+	  color = choose_different_color ();
+	  LW_NETWORK_INFO[i].color = color;
 	}
     }
 }
@@ -247,16 +233,17 @@ void lw_network_attribute_colors()
 /*
  * Associates a part to each team 
  */
-void lw_network_attribute_parts()
+void
+lw_network_attribute_parts ()
 {
   int i;
-  static int order[NB_TEAMS]={0,5,2,3,1,4};
+  static int order[NB_TEAMS] = { 0, 5, 2, 3, 1, 4 };
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
       if (LW_NETWORK_INFO[i].active)
 	{
-	  LW_NETWORK_INFO[i].part=order[LW_NETWORK_INFO[i].server_id];
+	  LW_NETWORK_INFO[i].part = order[LW_NETWORK_INFO[i].server_id];
 	}
     }
 }
