@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -82,91 +82,92 @@
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-int options (void)
+int
+options (void)
 {
   DIALOG d[12];
   DIALOG_PLAYER *dp;
-  int i,choix=4,retour=0;
+  int i, choix = 4, retour = 0;
   int old_gfx_menu;
   int old_fullscreen;
-  int gfxmode_change=0;
+  int gfxmode_change = 0;
 
-  memset(d,0,sizeof(d));
+  memset (d, 0, sizeof (d));
 
-  while (retour==0)
+  while (retour == 0)
     {
-      for (i=0; i<6; ++i)
-	standard_button (d+i+4,0,i,1,8);
-      standard_button (d+10,0,7,1,8);
+      for (i = 0; i < 6; ++i)
+	standard_button (d + i + 4, 0, i, 1, 8);
+      standard_button (d + 10, 0, 7, 1, 8);
 
-      quick_buttons(d);
-      d[4].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_GRAPHICS);
-      d[5].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_SOUND);
-      d[6].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_RULES);
-      d[7].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_SPEEDS);
-      d[8].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_CONTROLS);
-      d[9].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_LANGUAGE);
-      d[10].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_DEFAULT);
-      d[11].proc=0;
+      quick_buttons (d);
+      d[4].dp = lw_lang_string (LW_LANG_STRING_OPTIONS_GRAPHICS);
+      d[5].dp = lw_lang_string (LW_LANG_STRING_OPTIONS_SOUND);
+      d[6].dp = lw_lang_string (LW_LANG_STRING_OPTIONS_RULES);
+      d[7].dp = lw_lang_string (LW_LANG_STRING_OPTIONS_SPEEDS);
+      d[8].dp = lw_lang_string (LW_LANG_STRING_OPTIONS_CONTROLS);
+      d[9].dp = lw_lang_string (LW_LANG_STRING_OPTIONS_LANGUAGE);
+      d[10].dp = lw_lang_string (LW_LANG_STRING_OPTIONS_DEFAULT);
+      d[11].proc = 0;
 
-      old_gfx_menu=CONFIG_GFX_MENU;
-      old_fullscreen=CONFIG_FULLSCREEN;
+      old_gfx_menu = CONFIG_GFX_MENU;
+      old_fullscreen = CONFIG_FULLSCREEN;
 
-      display_back_image();
+      display_back_image ();
       if (gfxmode_change)
 	{
-	  gfxmode_change=0;
+	  gfxmode_change = 0;
 	  display_back_image ();
-	  dp=my_init_dialog (d,choix);
+	  dp = my_init_dialog (d, choix);
 	  my_fade_in ();
 	}
       else
 	{
-	  dp=my_init_dialog (d,choix);
+	  dp = my_init_dialog (d, choix);
 	}
 
-      show_mouse(screen);
+      show_mouse (screen);
       while (my_update_dialog (dp))
 	;
-      choix=shutdown_dialog (dp);
+      choix = shutdown_dialog (dp);
 
-      play_click();
+      play_click ();
 
       switch (choix)
 	{
 	case -1:
 	case MENU_QUICK_BACK:
-	  retour=1;
+	  retour = 1;
 	  break;
 	case MENU_QUICK_MAIN:
-	  retour=MENU_TOP;
+	  retour = MENU_TOP;
 	  break;
 	case MENU_QUICK_QUIT:
-	  if (confirm_quit())
-	    retour=MENU_EXIT;
+	  if (confirm_quit ())
+	    retour = MENU_EXIT;
 	  else
-	    display_back_image();
+	    display_back_image ();
 	  break;
 	case MENU_QUICK_PLAY:
-	  retour=MENU_PLAY;
+	  retour = MENU_PLAY;
 	  break;
 	case 4:
-	  retour=graphic_options ();
+	  retour = graphic_options ();
 	  break;
 	case 5:
-	  retour=sound_options ();
+	  retour = sound_options ();
 	  break;
 	case 6:
-	  retour=rules_options ();
+	  retour = rules_options ();
 	  break;
 	case 7:
-	  retour=speeds_options ();
+	  retour = speeds_options ();
 	  break;
 	case 8:
-	  retour=controls_options ();
+	  retour = controls_options ();
 	  break;
 	case 9:
-	  retour=language_options ();
+	  retour = language_options ();
 	  break;
 	case 10:
 	  load_default_options ();
@@ -174,25 +175,23 @@ int options (void)
 	  /*
 	   * The volume might have changed, so we update it
 	   */
-	  WATER_VOLUME=CONFIG_WATER_VOLUME_MENU;
+	  WATER_VOLUME = CONFIG_WATER_VOLUME_MENU;
 	  /*
 	   * If the graphics settings changed, we reflect them
 	   */
-	  if (old_gfx_menu!=CONFIG_GFX_MENU ||
-	      old_fullscreen!=CONFIG_FULLSCREEN)
+	  if (old_gfx_menu != CONFIG_GFX_MENU ||
+	      old_fullscreen != CONFIG_FULLSCREEN)
 	    {
-	      gfxmode_change=1;
-	      set_resolution(CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN,NULL);
+	      gfxmode_change = 1;
+	      set_resolution (CONFIG_GFX_MENU, 0, CONFIG_FULLSCREEN, NULL);
 	    }
-	  retour=0;
+	  retour = 0;
 	  break;
 	}
     }
 
-  if (retour>0)
+  if (retour > 0)
     retour--;
 
   return retour;
 }
-
-
