@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -77,19 +77,21 @@
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-int lw_sock_peek(int sock, int len)
+int
+lw_sock_peek (int sock, int len)
 {
-  int result=0;
+  int result = 0;
 
-  result=lw_sock_peek_ex(sock,len);
+  result = lw_sock_peek_ex (sock, len);
 
   return result;
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_send_str(int sock, char *str)
+int
+lw_sock_send_str (int sock, char *str)
 {
-  int result=0;
+  int result = 0;
   int limit_ticker;
 
   /*
@@ -97,12 +99,12 @@ int lw_sock_send_str(int sock, char *str)
    * UNIX functions do not work because allegro's timer messes
    * things up. Therefore we do our own dirty ugly select...
    */
-  limit_ticker=get_ticker()+LW_SOCK2CLI_TIMEOUT_MSEC;
-  while (limit_ticker>get_ticker() && !result)
+  limit_ticker = get_ticker () + LW_SOCK2CLI_TIMEOUT_MSEC;
+  while (limit_ticker > get_ticker () && !result)
     {
-      if (lw_sock_send_str_ex(sock,str))
+      if (lw_sock_send_str_ex (sock, str))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -110,9 +112,10 @@ int lw_sock_send_str(int sock, char *str)
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_recv_str(int sock, char *str)
+int
+lw_sock_recv_str (int sock, char *str)
 {
-  int result=0;
+  int result = 0;
   int limit_ticker;
 
   /*
@@ -120,12 +123,12 @@ int lw_sock_recv_str(int sock, char *str)
    * UNIX functions do not work because allegro's timer messes
    * things up. Therefore we do our own dirty ugly select...
    */
-  limit_ticker=get_ticker()+LW_SOCK2CLI_TIMEOUT_MSEC;
-  while (limit_ticker>get_ticker() && !result)
+  limit_ticker = get_ticker () + LW_SOCK2CLI_TIMEOUT_MSEC;
+  while (limit_ticker > get_ticker () && !result)
     {
-      if (lw_sock_recv_str_ex(sock,str))
+      if (lw_sock_recv_str_ex (sock, str))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -133,9 +136,10 @@ int lw_sock_recv_str(int sock, char *str)
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_send_buffer(int sock, char *buffer,int len)
+int
+lw_sock_send_buffer (int sock, char *buffer, int len)
 {
-  int result=0;
+  int result = 0;
   int limit_ticker;
 
   /*
@@ -143,12 +147,12 @@ int lw_sock_send_buffer(int sock, char *buffer,int len)
    * UNIX functions do not work because allegro's timer messes
    * things up. Therefore we do our own dirty ugly select...
    */
-  limit_ticker=get_ticker()+LW_SOCK2CLI_TIMEOUT_MSEC;
-  while (limit_ticker>get_ticker() && !result)
+  limit_ticker = get_ticker () + LW_SOCK2CLI_TIMEOUT_MSEC;
+  while (limit_ticker > get_ticker () && !result)
     {
-      if (lw_sock_send_buffer_ex(sock,buffer,len))
+      if (lw_sock_send_buffer_ex (sock, buffer, len))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -156,9 +160,10 @@ int lw_sock_send_buffer(int sock, char *buffer,int len)
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_recv_buffer(int sock, char *buffer, int len)
+int
+lw_sock_recv_buffer (int sock, char *buffer, int len)
 {
-  int result=0;
+  int result = 0;
   int limit_ticker;
 
   /*
@@ -166,22 +171,17 @@ int lw_sock_recv_buffer(int sock, char *buffer, int len)
    * UNIX functions do not work because allegro's timer messes
    * things up. Therefore we do our own dirty ugly select...
    */
-  limit_ticker=get_ticker()+LW_SOCK2CLI_TIMEOUT_MSEC;
-  while (limit_ticker>get_ticker() && !result)
+  limit_ticker = get_ticker () + LW_SOCK2CLI_TIMEOUT_MSEC;
+  while (limit_ticker > get_ticker () && !result)
     {
-      if (lw_sock_peek_ex(sock,len))
+      if (lw_sock_peek_ex (sock, len))
 	{
-	  if (lw_sock_recv_buffer_ex(sock,buffer,len))
+	  if (lw_sock_recv_buffer_ex (sock, buffer, len))
 	    {
-	      result=1;
+	      result = 1;
 	    }
 	}
     }
 
   return result;
 }
-
-
-
-
-
