@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -55,10 +55,10 @@
 #ifdef WIN32
 #include <winsock.h>
 #else
+#include <sys/types.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <sys/socket.h>
-#include <sys/types.h>
 #include <sys/time.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -79,9 +79,9 @@
 /*==================================================================*/
 
 #define LW_SOCK_RECV_SEC                  8
-#define LW_SOCK_RECV_USEC                 0 
+#define LW_SOCK_RECV_USEC                 0
 #define LW_SOCK_SEND_SEC                  8
-#define LW_SOCK_SEND_USEC                 0 
+#define LW_SOCK_SEND_USEC                 0
 
 #define LW_SOCK_SEND_BUFFER_SIZE        100
 #define LW_SOCK_RECV_BUFFER_SIZE        200
@@ -105,7 +105,7 @@
 /* static fonctions                                                 */
 /*==================================================================*/
 
-static void clean_buffer(char *buffer,int len);
+static void clean_buffer (char *buffer, int len);
 
 /*==================================================================*/
 /* fonctions                                                        */
@@ -116,15 +116,16 @@ static void clean_buffer(char *buffer,int len);
  * Cleans up a message buffer from all characters which are not
  * plain standard ASCII. Used for logging information.
  */
-static void clean_buffer(char *buffer,int len)
+static void
+clean_buffer (char *buffer, int len)
 {
   int i;
 
-  for (i=0;i<len;++i)
+  for (i = 0; i < len; ++i)
     {
-      if (!isalnum(buffer[i]) && buffer[i]!='-' && buffer[i]!='+')
+      if (!isalnum (buffer[i]) && buffer[i] != '-' && buffer[i] != '+')
 	{
-	  buffer[i]='.';
+	  buffer[i] = '.';
 	}
     }
 }
@@ -133,33 +134,34 @@ static void clean_buffer(char *buffer,int len)
 /*
  * Returns true if the given number bytes is available on the socket
  */
-int lw_sock_peek_ex(int sock,int len)
+int
+lw_sock_peek_ex (int sock, int len)
 {
-  int result=0;
+  int result = 0;
   int res;
   fd_set read;
   struct timeval tv;
   char buffer[LW_SOCK_MESSAGE_SIZE];
 
-  if (sock>=0)
+  if (sock >= 0)
     {
-      if (len<=LW_SOCK_MESSAGE_SIZE-1)
+      if (len <= LW_SOCK_MESSAGE_SIZE - 1)
 	{
-	  FD_ZERO(&read);
-	  FD_SET(sock,&read);
-	  tv.tv_sec=0;
-	  tv.tv_usec=0;
-	  res=select(sock+1,&read,NULL,NULL,&tv);
-	  if (res>0)
+	  FD_ZERO (&read);
+	  FD_SET (sock, &read);
+	  tv.tv_sec = 0;
+	  tv.tv_usec = 0;
+	  res = select (sock + 1, &read, NULL, NULL, &tv);
+	  if (res > 0)
 	    {
-	      if (FD_ISSET(sock,&read))
+	      if (FD_ISSET (sock, &read))
 		{
 		  /* 
 		   * First we test if there's enough data available
 		   */
-		  if (recv(sock,buffer,len,MSG_PEEK)==len)
+		  if (recv (sock, buffer, len, MSG_PEEK) == len)
 		    {
-		      result=1;
+		      result = 1;
 		    }
 		}
 	    }
@@ -174,11 +176,12 @@ int lw_sock_peek_ex(int sock,int len)
  * Sends a string on the network.
  * The advantage of this function over a raw "send" is that it does
  * a "strlen" automatically to know the length of the string, and
- * adds a tailing "\n" so that the message is "telnet compliant"
+ * adds a tailing CR+LF so that the message is "telnet/http compliant"
  */
-int lw_sock_send_str_ex(int sock, char *str)
+int
+lw_sock_send_str_ex (int sock, char *str)
 {
-  int result=0;
+  int result = 0;
   int len;
   char buffer[LW_SOCK_MESSAGE_SIZE];
   fd_set write;
@@ -187,75 +190,84 @@ int lw_sock_send_str_ex(int sock, char *str)
   int total_sent;
   int sent;
 
-  if (sock>=0)
+  if (sock >= 0)
     {
-      result=1;
+      result = 1;
 
       /*
        * We put the string in a buffer, since we'll probably have
-       * to modify it (cut if it's too long, add a tailing '\n').
+       * to modify it (cut if it's too long, add a tailing CR+LF).
        */
-      len=strlen(str);
-      len=MIN(len,LW_SOCK_MESSAGE_SIZE-2);
-      strncpy(buffer,str,len);
-      buffer[len]='\n';
+      len = strlen (str);
+      len = MIN (len, LW_SOCK_MESSAGE_SIZE - 3);
+      strncpy (buffer, str, len);
+      buffer[len] = '\r';
       ++len;
-      buffer[len]='\0';  
+      buffer[len] = '\n';
+      ++len;
+      buffer[len] = '\0';
 
-      total_sent=0;
-      while (total_sent<len && result)
+      total_sent = 0;
+      while (total_sent < len && result)
 	{
-	  FD_ZERO(&write);
-	  FD_SET(sock,&write);
-	  tv.tv_sec=LW_SOCK_SEND_SEC;
-	  tv.tv_usec=LW_SOCK_SEND_USEC;
+	  FD_ZERO (&write);
+	  FD_SET (sock, &write);
+	  tv.tv_sec = LW_SOCK_SEND_SEC;
+	  tv.tv_usec = LW_SOCK_SEND_USEC;
 
-	  errno=0;
-	  res=select(sock+1,NULL,&write,NULL,&tv);
+	  errno = 0;
+	  res = select (sock + 1, NULL, &write, NULL, &tv);
 
 	  switch (res)
 	    {
 	    case -1:
-	      if (errno!=EINTR)
+	      if (errno != EINTR)
 		{
-		  result=0;
+		  result = 0;
 		}
 	      break;
 	    case 1:
-	      if (FD_ISSET(sock,&write))
+	      if (FD_ISSET (sock, &write))
 		{
-		  sent=send(sock,buffer+total_sent,len-total_sent,0);
-		  if (sent>0 && sent<=len-total_sent)
+		  sent =
+		    send (sock, buffer + total_sent, len - total_sent, 0);
+		  if (sent > 0 && sent <= len - total_sent)
 		    {
-		      total_sent+=sent;
+		      total_sent += sent;
 		    }
 		  else
 		    {
-		      result=0;
+		      result = 0;
 		    }
 		}
 	      break;
 	    default:
-	      result=0;
+	      result = 0;
 	    }
 	}
 
       if (LW_SOCK_LOG)
 	{
-	  if (result)
+	  switch (result)
 	    {
-	      log_print_int(sock);
-	      log_print_str(" > \"");
-	      log_print_str(str);
-	      log_print_str("\"");
-	      log_println();
-	      log_flush();
-	    }
-	  else
-	    {
-	      log_print_int(sock);
-	      log_print_str(" > timeout!");
-	      log_println();
+	    case 1:
+	      log_print_int (sock);
+	      log_print_str (" > \"");
+	      log_print_str (str);
+	      log_print_str ("\"");
+	      log_println ();
+	      log_flush ();
+	      break;
+	    case 0:
+	      log_print_int (sock);
+	      log_print_str (" > timeout!");
+	      log_println ();
+	      break;
+	    default:
+	      log_print_int (sock);
+	      log_print_str (" > unexpected error!");
+	      log_println ();
+	      break;
 	    }
 	}
     }
@@ -275,21 +287,22 @@ int lw_sock_send_str_ex(int sock, char *str)
  * for more than a #define specified amount of time, it will return
  * an error.
  */
-int lw_sock_recv_str_ex(int sock, char *str)
+int
+lw_sock_recv_str_ex (int sock, char *str)
 {
-  int result=0;
-  int pos,l;
+  int result = 0;
+  int pos, l;
   int cr_found;
   char *cr;
   fd_set read;
   struct timeval tv;
   int res;
 
-  str[0]='\0';
+  str[0] = '\0';
 
-  if (sock>=0)
+  if (sock >= 0)
     {
-      result=1;
+      result = 1;
 
       /*
        * We keep on trying to get data until
@@ -297,24 +310,24 @@ int lw_sock_recv_str_ex(int sock, char *str)
        * - the size of incoming data exceeds LW_SOCK_MESSAGE_SIZE
        * - there's a reception low level error
        */
-      cr_found=0;
-      pos=0;
-      while (!cr_found && pos<LW_SOCK_MESSAGE_SIZE-1 && result>0)
+      cr_found = 0;
+      pos = 0;
+      while (!cr_found && pos < LW_SOCK_MESSAGE_SIZE - 1 && result > 0)
 	{
-	  FD_ZERO(&read);
-	  FD_SET(sock,&read);
-	  tv.tv_sec=LW_SOCK_RECV_SEC;
-	  tv.tv_usec=LW_SOCK_RECV_USEC;
+	  FD_ZERO (&read);
+	  FD_SET (sock, &read);
+	  tv.tv_sec = LW_SOCK_RECV_SEC;
+	  tv.tv_usec = LW_SOCK_RECV_USEC;
 
-	  errno=0;
-	  res=select(sock+1,&read,NULL,NULL,&tv);
+	  errno = 0;
+	  res = select (sock + 1, &read, NULL, NULL, &tv);
 
 	  switch (res)
 	    {
 	    case -1:
-	      if (errno!=EINTR)
+	      if (errno != EINTR)
 		{
-		  result=0;
+		  result = 0;
 		}
 	      break;
 	    case 1:
@@ -323,9 +336,9 @@ int lw_sock_recv_str_ex(int sock, char *str)
 	       * we are polling. If the event is not for us, let's consider
 	       * everything is fine...
 	       */
-	      if (!FD_ISSET(sock,&read))
+	      if (!FD_ISSET (sock, &read))
 		{
-		  result=1;
+		  result = 1;
 		}
 	      else
 		{
@@ -340,7 +353,7 @@ int lw_sock_recv_str_ex(int sock, char *str)
 		   * along with it, which caused some network inconsistency
 		   * since the messages had "disappeared".
 		   */
-		  if ((l=recv(sock,str+pos,1,0))<=0)
+		  if ((l = recv (sock, str + pos, 1, 0)) <= 0)
 		    {
 		      /*
 		       * OK, now we have received a message on this socket
@@ -348,8 +361,8 @@ int lw_sock_recv_str_ex(int sock, char *str)
 		       * the socket is dead, so we return -1 instead of 0
 		       * so that the caller can make the difference between
 		       * a timeout (0) and a dead socket (-1).
-		       */ 
-		      result=-1;
+		       */
+		      result = -1;
 		    }
 		  else
 		    {
@@ -359,17 +372,17 @@ int lw_sock_recv_str_ex(int sock, char *str)
 		       * have to call recv several times to retrieve the whole
 		       * message.
 		       */
-		      pos+=l;
+		      pos += l;
 		      /*
 		       * We add a tailing '\0' so that the string is "C compliant"
 		       */
-		      str[pos]=0;
+		      str[pos] = 0;
 		      /*
 		       * We seek for character 10, which should be '\n'
 		       */
-		      if ((cr=strchr(str,10))!=NULL)
+		      if ((cr = strchr (str, 10)) != NULL)
 			{
-			  cr_found=1;
+			  cr_found = 1;
 			  /*
 			   * We handle the special character '13' for very often,
 			   * especially when using telnet, the strings come
@@ -377,47 +390,58 @@ int lw_sock_recv_str_ex(int sock, char *str)
 			   * that after removing the 10 there's still a 13, then
 			   * we remove the 13 as well.
 			   */
-			  if ((cr-str)>=1 && (*(cr-1))==13)
+			  if ((cr - str) >= 1 && (*(cr - 1)) == 13)
 			    {
 			      /*
 			       * Let's cut this ugly "ascii 13" character
 			       * along with "ascii 10"
 			       */
-			      (*(cr-1))=0;
+			      (*(cr - 1)) = 0;
 			    }
 			  else
-			    {	
+			    {
 			      /*
 			       * No "ascii 13" in sight, simply remove "ascii 10"
 			       */
-			      (*cr)=0;
+			      (*cr) = 0;
 			    }
 			}
-		      result=1;
+		      result = 1;
 		    }
 		}
 	      break;
 	    default:
-	      result=0;
+	      result = 0;
 	    }
 	}
 
       if (LW_SOCK_LOG)
 	{
-	  if (result)
+	  switch (result)
 	    {
-	      log_print_int(sock);
-	      log_print_str(" < \"");
-	      log_print_str(str);
-	      log_print_str("\"");
-	      log_println();
-	      log_flush();
-	    }
-	  else
-	    {
-	      log_print_int(sock);
-	      log_print_str(" < timeout!");
-	      log_println();
+	    case 1:
+	      log_print_int (sock);
+	      log_print_str (" < \"");
+	      log_print_str (str);
+	      log_print_str ("\"");
+	      log_println ();
+	      log_flush ();
+	      break;
+	    case 0:
+	      log_print_int (sock);
+	      log_print_str (" < timeout!");
+	      log_println ();
+	      break;
+	    case -1:
+	      log_print_int (sock);
+	      log_print_str (" < closed!");
+	      log_println ();
+	      break;
+	    default:
+	      log_print_int (sock);
+	      log_print_str (" < unexpected error!");
+	      log_println ();
+	      break;
 	    }
 	}
     }
@@ -430,9 +454,10 @@ int lw_sock_recv_str_ex(int sock, char *str)
  * Sends a buffer on the network.
  * Only a standard send wrapper
  */
-int lw_sock_send_buffer_ex(int sock, char *buffer,int len)
+int
+lw_sock_send_buffer_ex (int sock, char *buffer, int len)
 {
-  int result=0;
+  int result = 0;
   char trace[LW_SOCK_MESSAGE_SIZE];
   fd_set write;
   struct timeval tv;
@@ -440,84 +465,83 @@ int lw_sock_send_buffer_ex(int sock, char *buffer,int len)
   int total_sent;
   int sent;
 
-  if (sock>=0)
+  if (sock >= 0)
     {
-      result=1;
+      result = 1;
 
-      if (len<=LW_SOCK_MESSAGE_SIZE-1)
+      if (len <= LW_SOCK_MESSAGE_SIZE - 1)
 	{
-	  total_sent=0;
-	  while (total_sent<len && result)
+	  total_sent = 0;
+	  while (total_sent < len && result)
 	    {
-	      FD_ZERO(&write);
-	      FD_SET(sock,&write);
-	      tv.tv_sec=LW_SOCK_SEND_SEC;
-	      tv.tv_usec=LW_SOCK_SEND_USEC;
+	      FD_ZERO (&write);
+	      FD_SET (sock, &write);
+	      tv.tv_sec = LW_SOCK_SEND_SEC;
+	      tv.tv_usec = LW_SOCK_SEND_USEC;
+
+	      errno = 0;
+	      res = select (sock + 1, NULL, &write, NULL, &tv);
 
-	      errno=0;
-	      res=select(sock+1,NULL,&write,NULL,&tv);
-	  
 	      switch (res)
 		{
 		case -1:
-		  if (errno!=EINTR)
+		  if (errno != EINTR)
 		    {
-		      result=0;
+		      result = 0;
 		    }
 		  break;
 		case 1:
-		  if (FD_ISSET(sock,&write))
+		  if (FD_ISSET (sock, &write))
 		    {
-		      sent=send(sock,
-				buffer+total_sent,
-				MIN(len-total_sent,
-				    LW_SOCK_SEND_BUFFER_SIZE),
-				0);
-		      if (sent>0 && sent<=len-total_sent)
+		      sent = send (sock,
+				   buffer + total_sent,
+				   MIN (len - total_sent,
+					LW_SOCK_SEND_BUFFER_SIZE), 0);
+		      if (sent > 0 && sent <= len - total_sent)
 			{
-			  total_sent+=sent;
+			  total_sent += sent;
 			}
 		      else
 			{
-			  result=0;
+			  result = 0;
 			}
 		    }
 		  break;
 		default:
-		  result=0;
+		  result = 0;
 		}
 	    }
-      
+
 	  if (LW_SOCK_LOG)
 	    {
 	      if (result)
 		{
-		  strncpy(trace,buffer,len);
-		  trace[len]='\0';
-		  log_print_int(sock);
-		  log_print_str(" > [");
-		  clean_buffer(trace,len);
-		  log_print_str(trace);
-		  log_print_str("]");
-		  log_println();
-		  log_flush();
+		  strncpy (trace, buffer, len);
+		  trace[len] = '\0';
+		  log_print_int (sock);
+		  log_print_str (" > [");
+		  clean_buffer (trace, len);
+		  log_print_str (trace);
+		  log_print_str ("]");
+		  log_println ();
+		  log_flush ();
 		}
 	      else
 		{
-		  log_print_int(sock);
-		  log_print_str(" > timeout!");
-		  log_println();
+		  log_print_int (sock);
+		  log_print_str (" > timeout!");
+		  log_println ();
 		}
 	    }
 	}
       else
 	{
-	  result=0;
+	  result = 0;
 	  if (LW_SOCK_LOG)
 	    {
-	      log_print_int(sock);
-	      log_print_str(" > message too large!");
-	      log_println();
+	      log_print_int (sock);
+	      log_print_str (" > message too large!");
+	      log_println ();
 	    }
 	}
     }
@@ -530,9 +554,10 @@ int lw_sock_send_buffer_ex(int sock, char *buffer,int len)
  * Receives a buffer on the network.
  * Only a standard recv wrapper
  */
-int lw_sock_recv_buffer_ex(int sock, char *buffer,int len)
+int
+lw_sock_recv_buffer_ex (int sock, char *buffer, int len)
 {
-  int result=0;
+  int result = 0;
   char trace[LW_SOCK_MESSAGE_SIZE];
   int res;
   fd_set read;
@@ -540,91 +565,88 @@ int lw_sock_recv_buffer_ex(int sock, char *buffer,int len)
   int total_received;
   int received;
 
-  memset(buffer,0,len);
+  memset (buffer, 0, len);
 
-  if (sock>=0)
+  if (sock >= 0)
     {
-      result=1;
+      result = 1;
 
-      if (len<=LW_SOCK_MESSAGE_SIZE-1)
+      if (len <= LW_SOCK_MESSAGE_SIZE - 1)
 	{
-	  total_received=0;
-	  while (total_received<len && result)
+	  total_received = 0;
+	  while (total_received < len && result)
 	    {
-	      FD_ZERO(&read);
-	      FD_SET(sock,&read);
-	      tv.tv_sec=LW_SOCK_RECV_SEC;
-	      tv.tv_usec=LW_SOCK_RECV_USEC;
+	      FD_ZERO (&read);
+	      FD_SET (sock, &read);
+	      tv.tv_sec = LW_SOCK_RECV_SEC;
+	      tv.tv_usec = LW_SOCK_RECV_USEC;
 
-	      errno=0;
-	      res=select(sock+1,&read,NULL,NULL,&tv);
+	      errno = 0;
+	      res = select (sock + 1, &read, NULL, NULL, &tv);
 
 	      switch (res)
 		{
 		case -1:
-		  if (errno!=EINTR)
+		  if (errno != EINTR)
 		    {
-		      result=0;
+		      result = 0;
 		    }
 		  break;
 		case 1:
-		  if (FD_ISSET(sock,&read))
+		  if (FD_ISSET (sock, &read))
 		    {
-		      received=recv(sock,
-				    buffer+total_received,
-				    MIN(len-total_received,
-					LW_SOCK_RECV_BUFFER_SIZE),
-				    0);
-		      if (received>0 && received<=len-total_received)
+		      received = recv (sock,
+				       buffer + total_received,
+				       MIN (len - total_received,
+					    LW_SOCK_RECV_BUFFER_SIZE), 0);
+		      if (received > 0 && received <= len - total_received)
 			{
-			  total_received+=received;
+			  total_received += received;
 			}
 		      else
 			{
-			  result=0;
+			  result = 0;
 			}
 		    }
 		  break;
 		default:
-		  result=0;
+		  result = 0;
 		}
 	    }
-      
+
 	  if (LW_SOCK_LOG)
 	    {
 	      if (result)
 		{
-		  strncpy(trace,buffer,len);
-		  trace[len]='\0';
-		  log_print_int(sock);
-		  log_print_str(" < [");
-		  clean_buffer(trace,len);
-		  log_print_str(trace);
-		  log_print_str("]");
-		  log_println();
-		  log_flush();
+		  strncpy (trace, buffer, len);
+		  trace[len] = '\0';
+		  log_print_int (sock);
+		  log_print_str (" < [");
+		  clean_buffer (trace, len);
+		  log_print_str (trace);
+		  log_print_str ("]");
+		  log_println ();
+		  log_flush ();
 		}
 	      else
 		{
-		  log_print_int(sock);
-		  log_print_str(" < timeout!");
-		  log_println();
+		  log_print_int (sock);
+		  log_print_str (" < timeout!");
+		  log_println ();
 		}
 	    }
 	}
       else
 	{
-	  result=0;
+	  result = 0;
 	  if (LW_SOCK_LOG)
 	    {
-	      log_print_int(sock);
-	      log_print_str(" < message too large!");
-	      log_println();
+	      log_print_int (sock);
+	      log_print_str (" < message too large!");
+	      log_println ();
 	    }
 	}
     }
 
   return result;
 }
-
-
