@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -59,20 +59,20 @@
 /* variables globales                                               */
 /*==================================================================*/
 
-int WATER_VOLUME=0;
+int WATER_VOLUME = 0;
 
 #define HASARD_SIZE 1024
 static int HASARD_VALUE[HASARD_SIZE];
 static int HASARD_INDEX;
 
-static int SOUND_VOLUME_VALUES[17]=
-       { 0,
-	 8,10,13,16,
-         20,25,32,40,
-         51,64,81,101,
-         128,161,204,255};
+static int SOUND_VOLUME_VALUES[17] = { 0,
+  8, 10, 13, 16,
+  20, 25, 32, 40,
+  51, 64, 81, 101,
+  128, 161, 204, 255
+};
 
-static int WATER_DELAY=2000;
+static int WATER_DELAY = 2000;
 
 /*==================================================================*/
 /* fonctions                                                        */
@@ -83,114 +83,121 @@ static int WATER_DELAY=2000;
 /*------------------------------------------------------------------*/
 
 /*------------------------------------------------------------------*/
-static void water_handler (void)
+static void
+water_handler (void)
 {
- int    pan;
- int    hasard;
+  int pan;
+  int hasard;
 
- HASARD_INDEX++;
- HASARD_INDEX=HASARD_INDEX%HASARD_SIZE;
+  HASARD_INDEX++;
+  HASARD_INDEX = HASARD_INDEX % HASARD_SIZE;
 
- if (WATER_VOLUME>0)
+  if (WATER_VOLUME > 0)
     {
-     if (HASARD_INDEX%2)
-        pan=192;
-     else
-         pan=64;
+      if (HASARD_INDEX % 2)
+	pan = 192;
+      else
+	pan = 64;
 
-     hasard=HASARD_VALUE[HASARD_INDEX]%SAMPLE_WATER_NUMBER;
-     play_sample (SAMPLE_WATER [hasard],
-                 SOUND_VOLUME_VALUES[WATER_VOLUME],
-                 pan, 1000, 0);
+      hasard = HASARD_VALUE[HASARD_INDEX] % SAMPLE_WATER_NUMBER;
+      play_sample (SAMPLE_WATER[hasard],
+		   SOUND_VOLUME_VALUES[WATER_VOLUME], pan, 1000, 0);
     }
 }
+
 END_OF_FUNCTION (water_handler);
 
 /*------------------------------------------------------------------*/
-int start_water (void)
+int
+start_water (void)
 {
- int result=1;
- int i;
+  int result = 1;
+  int i;
 
- for (i=0; i<HASARD_SIZE; ++i)
-    HASARD_VALUE [i]=rand ()+i;
+  for (i = 0; i < HASARD_SIZE; ++i)
+    HASARD_VALUE[i] = random () + i;
 
- if (LOADED_WATER)
+  if (LOADED_WATER)
     {
-     WATER_VOLUME=CONFIG_WATER_VOLUME_MENU;
+      WATER_VOLUME = CONFIG_WATER_VOLUME_MENU;
 
-     LOCK_FUNCTION (water_handler);
-     LOCK_VARIABLE (HASARD_INDEX);
-     LOCK_VARIABLE (HASARD_VALUE);
-     LOCK_VARIABLE (SAMPLE_WATER);
-     LOCK_VARIABLE (WATER_VOLUME);
-     LOCK_VARIABLE (SOUND_VOLUME_VALUES);
+      LOCK_FUNCTION (water_handler);
+      LOCK_VARIABLE (HASARD_INDEX);
+      LOCK_VARIABLE (HASARD_VALUE);
+      LOCK_VARIABLE (SAMPLE_WATER);
+      LOCK_VARIABLE (WATER_VOLUME);
+      LOCK_VARIABLE (SOUND_VOLUME_VALUES);
 
-	#ifdef ALLEGRO_DOS
-     _go32_dpmi_lock_data (HASARD_VALUE,HASARD_SIZE*sizeof(int));
-     _go32_dpmi_lock_data (SOUND_VOLUME_VALUES,17*sizeof(int));
-	#endif
+#ifdef ALLEGRO_DOS
+      _go32_dpmi_lock_data (HASARD_VALUE, HASARD_SIZE * sizeof (int));
+      _go32_dpmi_lock_data (SOUND_VOLUME_VALUES, 17 * sizeof (int));
+#endif
 
-     result=install_int_ex (water_handler,
-                            MSEC_TO_TIMER (WATER_DELAY));
-     water_handler ();
+      result = install_int_ex (water_handler, MSEC_TO_TIMER (WATER_DELAY));
+      water_handler ();
     }
- return result;
+  return result;
 }
 
 /*------------------------------------------------------------------*/
-void stop_water (void)
+void
+stop_water (void)
 {
- remove_int (water_handler);
+  remove_int (water_handler);
 }
 
 /*------------------------------------------------------------------*/
-static void my_play_sample (SAMPLE *s, int vol)
+static void
+my_play_sample (SAMPLE * s, int vol)
 {
- if (vol>0)
-    play_sample (s, SOUND_VOLUME_VALUES[vol-1], 128, 1000, 0);
+  if (vol > 0)
+    play_sample (s, SOUND_VOLUME_VALUES[vol - 1], 128, 1000, 0);
 }
 
 /*------------------------------------------------------------------*/
-void play_click (void)
+void
+play_click (void)
 {
- if (LOADED_SFX)
-  my_play_sample (SAMPLE_SFX_CLICK, CONFIG_CLICK_VOLUME);
+  if (LOADED_SFX)
+    my_play_sample (SAMPLE_SFX_CLICK, CONFIG_CLICK_VOLUME);
 }
 
 /*------------------------------------------------------------------*/
-void play_go (void)
+void
+play_go (void)
 {
- if (LOADED_SFX)
-  my_play_sample (SAMPLE_SFX_GO, CONFIG_SFX_VOLUME);
+  if (LOADED_SFX)
+    my_play_sample (SAMPLE_SFX_GO, CONFIG_SFX_VOLUME);
 }
 
 /*------------------------------------------------------------------*/
-void play_win (void)
+void
+play_win (void)
 {
- if (LOADED_SFX)
-  my_play_sample (SAMPLE_SFX_WIN, CONFIG_SFX_VOLUME);
+  if (LOADED_SFX)
+    my_play_sample (SAMPLE_SFX_WIN, CONFIG_SFX_VOLUME);
 }
 
 /*------------------------------------------------------------------*/
-void play_time (void)
+void
+play_time (void)
 {
- if (LOADED_SFX)
-  my_play_sample (SAMPLE_SFX_TIME, CONFIG_SFX_VOLUME);
+  if (LOADED_SFX)
+    my_play_sample (SAMPLE_SFX_TIME, CONFIG_SFX_VOLUME);
 }
 
 /*------------------------------------------------------------------*/
-void play_loose (void)
+void
+play_loose (void)
 {
- if (LOADED_SFX)
-  my_play_sample (SAMPLE_SFX_LOOSE, CONFIG_SFX_VOLUME);
+  if (LOADED_SFX)
+    my_play_sample (SAMPLE_SFX_LOOSE, CONFIG_SFX_VOLUME);
 }
 
 /*------------------------------------------------------------------*/
-void play_connect (void)
+void
+play_connect (void)
 {
- if (LOADED_SFX)
-  my_play_sample (SAMPLE_SFX_CONNECT, CONFIG_SFX_VOLUME);
+  if (LOADED_SFX)
+    my_play_sample (SAMPLE_SFX_CONNECT, CONFIG_SFX_VOLUME);
 }
-
-
