@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -70,22 +70,22 @@ typedef struct
   int nb_teams;
   int nb_chans;
   LW_SRVCHAN chan[NB_TEAMS];
-} LW_SRVCONT;
+}
+LW_SRVCONT;
 
 /*==================================================================*/
 /* fonctions globales                                               */
 /*==================================================================*/
 
-int lw_srvcont_wait_teams(LW_SRVCONT *cont, 
-			  LW_WWWSRV_DATA *www_data,
-			  int nb_teams,int port,
-			  char *password);
-int lw_srvcont_tell_who(LW_SRVCONT *cont);
-int lw_srvcont_final_ok(LW_SRVCONT *cont);
-int lw_srvcont_replicate_keys(LW_SRVCONT *cont,
-			      LW_WWWSRV_DATA *www_data,
-			      int lag,
-			      char *password);
-void lw_srvcont_close(LW_SRVCONT *cont);
+int lw_srvcont_wait_teams (LW_SRVCONT * cont,
+			   LW_WWWSRV_DATA * www_data,
+			   int nb_teams, int port,
+			   char *password, char *callback);
+int lw_srvcont_tell_who (LW_SRVCONT * cont);
+int lw_srvcont_final_ok (LW_SRVCONT * cont);
+int lw_srvcont_replicate_keys (LW_SRVCONT * cont,
+			       LW_WWWSRV_DATA * www_data,
+			       int lag, char *password);
+void lw_srvcont_close (LW_SRVCONT * cont);
 
 #endif
