@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -52,6 +52,7 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#include <stdlib.h>
 
 #include "srvteam.h"
 
@@ -63,12 +64,14 @@
 /*
  * Resets the LW_SRVTEAM struct
  */
-void lw_srvteam_reset(LW_SRVTEAM *team)
+void
+lw_srvteam_reset (LW_SRVTEAM * team)
 {
-  team->active=0;
-  team->network=0;
-  team->server_id=0;
-  team->control_type=0;
-  team->name[0]='\0';
-}
+  memset (team, 0, sizeof (LW_SRVTEAM));
 
+  team->active = 0;
+  team->network = 0;
+  team->server_id = 0;
+  team->control_type = 0;
+  team->name[0] = '\0';
+}
