@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -65,23 +65,16 @@
 /*
  * returns the "CPU time" in seconds
  */
-int lw_srvtime_seconds()
+int
+lw_srvtime_seconds ()
 {
   int result;
 
 #ifdef WIN32
-  result=GetTickCount()/1000;
+  result = GetTickCount () / 1000;
 #else
-  result=time(NULL);
-#endif  
+  result = time (NULL);
+#endif
 
   return result;
 }
-
-
-
-
-
-
-
-
