@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -59,6 +59,7 @@
 #include "parser.h"
 #include "startup.h"
 #include "server.h"
+#include "macro.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -93,50 +94,50 @@
 #define STARTUP_MAX_METASERVER_LENGTH      200
 
 #ifdef ALLEGRO_DOS
-int STARTUP_BIG_DATA=8;
+int STARTUP_BIG_DATA = 8;
 #else
-int STARTUP_BIG_DATA=16;
+int STARTUP_BIG_DATA = 16;
 #endif
-int STARTUP_DIGI_CARD=DIGI_AUTODETECT;
-int STARTUP_MIDI_CARD=MIDI_AUTODETECT;
-int STARTUP_JOYSTICK_ON=1;
-int STARTUP_BACK_STATE=1;
-int STARTUP_TEXTURE_STATE=1;
-int STARTUP_WATER_STATE=1;
-int STARTUP_SFX_STATE=1;
-int STARTUP_MUSIC_STATE=1;
-int STARTUP_CUSTOM_STATE=1;
-int STARTUP_ASM=1;
-int STARTUP_SVGA=1;
-int STARTUP_STOP=0;
-int STARTUP_AUTO=0;
-int STARTUP_CHECK=0;
-int STARTUP_CAPTURE=0;
-int STARTUP_TOMBOLA=0;
+int STARTUP_DIGI_CARD = DIGI_AUTODETECT;
+int STARTUP_MIDI_CARD = MIDI_AUTODETECT;
+int STARTUP_JOYSTICK_ON = 1;
+int STARTUP_BACK_STATE = 1;
+int STARTUP_TEXTURE_STATE = 1;
+int STARTUP_WATER_STATE = 1;
+int STARTUP_SFX_STATE = 1;
+int STARTUP_MUSIC_STATE = 1;
+int STARTUP_CUSTOM_STATE = 1;
+int STARTUP_ASM = 1;
+int STARTUP_SVGA = 1;
+int STARTUP_STOP = 0;
+int STARTUP_AUTO = 0;
+int STARTUP_CHECK = 0;
+int STARTUP_CAPTURE = 0;
+int STARTUP_TOMBOLA = 0;
 
 #ifdef ALLEGRO_UNIX
-static char *DEFAULT_CFG_PATH=CONFIG_UNIX_CFG;
-static char *DEFAULT_LOG_PATH="";
-static char *DEFAULT_DAT_PATH=CONFIG_UNIX_DAT;
-static char *DEFAULT_MAP_PATH=CONFIG_UNIX_MAP;
-static char *DEFAULT_TEX_PATH=CONFIG_UNIX_TEX;
-static char *DEFAULT_MID_PATH=CONFIG_UNIX_MID;
+static char *DEFAULT_CFG_PATH = CONFIG_UNIX_CFG;
+static char *DEFAULT_LOG_PATH = "";
+static char *DEFAULT_DAT_PATH = CONFIG_UNIX_DAT;
+static char *DEFAULT_MAP_PATH = CONFIG_UNIX_MAP;
+static char *DEFAULT_TEX_PATH = CONFIG_UNIX_TEX;
+static char *DEFAULT_MID_PATH = CONFIG_UNIX_MID;
 #else
 #ifdef ALLEGRO_WINDOWS
-static char *DEFAULT_CFG_PATH="data/lwwin.cfg";
-static char *DEFAULT_LOG_PATH="data/lwwin.log";
+static char *DEFAULT_CFG_PATH = "data/lwwin.cfg";
+static char *DEFAULT_LOG_PATH = "data/lwwin.log";
 #endif
 #ifdef ALLEGRO_DOS
-static char *DEFAULT_CFG_PATH="data/lwdos.cfg";
-static char *DEFAULT_LOG_PATH="data/lwdos.log";
+static char *DEFAULT_CFG_PATH = "data/lwdos.cfg";
+static char *DEFAULT_LOG_PATH = "data/lwdos.log";
 #endif
-static char *DEFAULT_DAT_PATH="data/lw.dat";
-static char *DEFAULT_MAP_PATH="custom/map/";
-static char *DEFAULT_TEX_PATH="custom/texture/";
-static char *DEFAULT_MID_PATH="custom/music/";
+static char *DEFAULT_DAT_PATH = "data/lw.dat";
+static char *DEFAULT_MAP_PATH = "custom/map/";
+static char *DEFAULT_TEX_PATH = "custom/texture/";
+static char *DEFAULT_MID_PATH = "custom/music/";
 #endif
 
-static char *DEFAULT_METASERVER=LW_SERVER_DEFAULT_METASERVER;
+static char *DEFAULT_METASERVER = LW_SERVER_DEFAULT_METASERVER;
 
 char STARTUP_CFG_PATH[STARTUP_MAX_PATH_LENGTH];
 char STARTUP_DAT_PATH[STARTUP_MAX_PATH_LENGTH];
@@ -152,198 +153,222 @@ char STARTUP_METASERVER[STARTUP_MAX_METASERVER_LENGTH];
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-static void set_bigdata_size (void)
+static void
+set_bigdata_size (void)
 {
   int bigd;
 
-  if (exist_argument_value(IDENT_MEM))
+  if (exist_argument_value (IDENT_MEM))
     {
-      bigd=get_argument_int(IDENT_MEM);
-      if (bigd<1)
-        bigd=1;
-      if (bigd>LW_STARTUP_MEM_MAX)
-        bigd=LW_STARTUP_MEM_MAX;
-      STARTUP_BIG_DATA=bigd;
+      bigd = get_argument_int (IDENT_MEM);
+      if (bigd < 1)
+	bigd = 1;
+      if (bigd > LW_STARTUP_MEM_MAX)
+	bigd = LW_STARTUP_MEM_MAX;
+      STARTUP_BIG_DATA = bigd;
     }
 }
 
 /*------------------------------------------------------------------*/
-static void set_joystick (void)
+static void
+set_joystick (void)
 {
   if (exist_argument (IDENT_NOJOY))
-    STARTUP_JOYSTICK_ON=0;
+    STARTUP_JOYSTICK_ON = 0;
 }
 
 /*------------------------------------------------------------------*/
-static void set_load_states (void)
+static void
+set_load_states (void)
 {
   if (exist_argument (IDENT_NOBACK))
-    STARTUP_BACK_STATE=0;
+    STARTUP_BACK_STATE = 0;
   if (exist_argument (IDENT_NOTEXTURE))
-    STARTUP_TEXTURE_STATE=0;
+    STARTUP_TEXTURE_STATE = 0;
 
-  if (exist_argument (IDENT_NOWATER)
-      || exist_argument (IDENT_NOSOUND))
-    STARTUP_WATER_STATE=0;
-  if (exist_argument (IDENT_NOSFX)
-      || exist_argument (IDENT_NOSOUND))
-    STARTUP_SFX_STATE=0;
+  if (exist_argument (IDENT_NOWATER) || exist_argument (IDENT_NOSOUND))
+    STARTUP_WATER_STATE = 0;
+  if (exist_argument (IDENT_NOSFX) || exist_argument (IDENT_NOSOUND))
+    STARTUP_SFX_STATE = 0;
 
   if (exist_argument (IDENT_NOSOUND)
-      || ( exist_argument (IDENT_NOSFX)
-	   && exist_argument (IDENT_NOWATER)))
-    STARTUP_DIGI_CARD=DIGI_NONE;
+      || (exist_argument (IDENT_NOSFX) && exist_argument (IDENT_NOWATER)))
+    STARTUP_DIGI_CARD = DIGI_NONE;
 
-  if (exist_argument (IDENT_NOMUSIC)
-      || ( exist_argument (IDENT_NOSOUND)))
+  if (exist_argument (IDENT_NOMUSIC) || (exist_argument (IDENT_NOSOUND)))
     {
-      STARTUP_MUSIC_STATE=0;
-      STARTUP_MIDI_CARD=MIDI_NONE;
+      STARTUP_MUSIC_STATE = 0;
+      STARTUP_MIDI_CARD = MIDI_NONE;
     }
- 
+
   if (exist_argument (IDENT_NOCUSTOM))
-    STARTUP_CUSTOM_STATE=0;
+    STARTUP_CUSTOM_STATE = 0;
 }
 
 /*------------------------------------------------------------------*/
-static void set_graphic_possibilities (void)
+static void
+set_graphic_possibilities (void)
 {
   if (exist_argument (IDENT_NOSVGA))
-    STARTUP_SVGA=0;
+    STARTUP_SVGA = 0;
 }
 
 /*------------------------------------------------------------------*/
-static void set_c_or_asm (void)
+static void
+set_c_or_asm (void)
 {
   if (exist_argument (IDENT_NOASM))
-    STARTUP_ASM=0;
+    STARTUP_ASM = 0;
 }
 
 /*------------------------------------------------------------------*/
-static void set_stop (void)
+static void
+set_stop (void)
 {
   if (exist_argument (IDENT_STOP))
-    STARTUP_STOP=1;
+    STARTUP_STOP = 1;
 }
 
 /*------------------------------------------------------------------*/
-static void set_auto_check (void)
+static void
+set_auto_check (void)
 {
   if (exist_argument (IDENT_AUTO))
     {
-      STARTUP_AUTO=1;
-      STARTUP_CHECK=0;
+      STARTUP_AUTO = 1;
+      STARTUP_CHECK = 0;
     }
   if (exist_argument (IDENT_CHECK))
     {
-      STARTUP_AUTO=0;
-      STARTUP_CHECK=1;
-      STARTUP_STOP=1;
+      STARTUP_AUTO = 0;
+      STARTUP_CHECK = 1;
+      STARTUP_STOP = 1;
     }
 }
 
 /*------------------------------------------------------------------*/
-static void set_safe (void)
+static void
+set_safe (void)
 {
   if (exist_argument (IDENT_NICE))
     {
-      STARTUP_BIG_DATA=4096;
-      STARTUP_SVGA=0;
+      STARTUP_BIG_DATA = 4096;
+      STARTUP_SVGA = 0;
     }
 
   if (exist_argument (IDENT_SAFE))
     {
-      STARTUP_JOYSTICK_ON=0;
-      STARTUP_BIG_DATA=1024;
-      STARTUP_DIGI_CARD=DIGI_NONE;
-      STARTUP_BACK_STATE=0;
-      STARTUP_TEXTURE_STATE=0;
-      STARTUP_WATER_STATE=0;
-      STARTUP_SFX_STATE=0;
-      STARTUP_MUSIC_STATE=0;
-      STARTUP_CUSTOM_STATE=0;
-      STARTUP_SVGA=0;
+      STARTUP_JOYSTICK_ON = 0;
+      STARTUP_BIG_DATA = 1024;
+      STARTUP_DIGI_CARD = DIGI_NONE;
+      STARTUP_BACK_STATE = 0;
+      STARTUP_TEXTURE_STATE = 0;
+      STARTUP_WATER_STATE = 0;
+      STARTUP_SFX_STATE = 0;
+      STARTUP_MUSIC_STATE = 0;
+      STARTUP_CUSTOM_STATE = 0;
+      STARTUP_SVGA = 0;
     }
 }
 
 /*------------------------------------------------------------------*/
-static void correct_path_dir (char *path)
+static void
+correct_path_dir (char *path)
 {
   int l;
   char c;
 
-  l=strlen (path);
-  if (l>0)
+  l = strlen (path);
+  if (l > 0)
     {
-      c=path[l-1];
-      if (c=='/' || c=='\\')
+      c = path[l - 1];
+      if (c == '/' || c == '\\')
 	{
-	  path[--l]=0;
+	  path[--l] = 0;
 	}
     }
 
-  fix_filename_case(path);
-  fix_filename_slashes(path);
+  fix_filename_case (path);
+  fix_filename_slashes (path);
 }
 
 /*------------------------------------------------------------------*/
-static void correct_path_file (char *path)
+static void
+correct_path_file (char *path)
 {
-  fix_filename_case(path);
-  fix_filename_slashes(path);
+  fix_filename_case (path);
+  fix_filename_slashes (path);
 }
 
 /*------------------------------------------------------------------*/
-static void set_path (void)
+static void
+set_path (void)
 {
   char home_path[512];
-  char *home_env;
+  char *home_env = NULL;
 
   if (exist_argument_value (IDENT_CFG))
-    strcpy(STARTUP_CFG_PATH,get_argument_str (IDENT_CFG));
+    {
+      LW_MACRO_STRCPY (STARTUP_CFG_PATH, get_argument_str (IDENT_CFG));
+    }
   else
     {
 #ifdef ALLEGRO_UNIX
-      home_env=getenv("HOME");
+      home_env = getenv ("HOME");
       if (home_env != NULL)
 	{
-	  strcpy(home_path,home_env);
-	  strcat(home_path,"/");
+	  LW_MACRO_SPRINTF1 (home_path, "%s/", home_env);
 	}
       else
 	{
-	  home_env="";
-	  strcpy(home_path,home_env);
-	}	
+	  home_env = "";
+	  LW_MACRO_STRCPY (home_path, home_env);
+	}
 #else
-      home_env="";
-      strcpy(home_path,home_env);
+      home_env = "";
+      LW_MACRO_STRCPY (home_path, home_env);
 #endif
-      strcpy(STARTUP_CFG_PATH,home_path);
-      strcat(STARTUP_CFG_PATH,DEFAULT_CFG_PATH);
+      LW_MACRO_SPRINTF2 (STARTUP_CFG_PATH, "%s%s", home_path,
+			 DEFAULT_CFG_PATH);
     }
 
-  strcpy(STARTUP_LOG_PATH,DEFAULT_LOG_PATH);
+  LW_MACRO_STRCPY (STARTUP_LOG_PATH, DEFAULT_LOG_PATH);
 
   if (exist_argument_value (IDENT_DAT))
-    strcpy(STARTUP_DAT_PATH,get_argument_str (IDENT_DAT));
+    {
+      LW_MACRO_STRCPY (STARTUP_DAT_PATH, get_argument_str (IDENT_DAT));
+    }
   else
-    strcpy(STARTUP_DAT_PATH,DEFAULT_DAT_PATH);
+    {
+      LW_MACRO_STRCPY (STARTUP_DAT_PATH, DEFAULT_DAT_PATH);
+    }
 
   if (exist_argument_value (IDENT_TEX))
-    strcpy(STARTUP_TEX_PATH,get_argument_str (IDENT_TEX));
+    {
+      LW_MACRO_STRCPY (STARTUP_TEX_PATH, get_argument_str (IDENT_TEX));
+    }
   else
-    strcpy(STARTUP_TEX_PATH,DEFAULT_TEX_PATH);
+    {
+      LW_MACRO_STRCPY (STARTUP_TEX_PATH, DEFAULT_TEX_PATH);
+    }
 
   if (exist_argument_value (IDENT_MAP))
-    strcpy(STARTUP_MAP_PATH,get_argument_str (IDENT_MAP));
+    {
+      LW_MACRO_STRCPY (STARTUP_MAP_PATH, get_argument_str (IDENT_MAP));
+    }
   else
-    strcpy(STARTUP_MAP_PATH,DEFAULT_MAP_PATH);
+    {
+      LW_MACRO_STRCPY (STARTUP_MAP_PATH, DEFAULT_MAP_PATH);
+    }
 
   if (exist_argument_value (IDENT_MID))
-    strcpy(STARTUP_MID_PATH,get_argument_str (IDENT_MID));
+    {
+      LW_MACRO_STRCPY (STARTUP_MID_PATH, get_argument_str (IDENT_MID));
+    }
   else
-    strcpy(STARTUP_MID_PATH,DEFAULT_MID_PATH);
+    {
+      LW_MACRO_STRCPY (STARTUP_MID_PATH, DEFAULT_MID_PATH);
+    }
 
 
   correct_path_file (STARTUP_CFG_PATH);
@@ -355,29 +380,37 @@ static void set_path (void)
 }
 
 /*------------------------------------------------------------------*/
-static void set_metaserver (void)
+static void
+set_metaserver (void)
 {
   if (exist_argument_value (IDENT_METASERVER))
-    strcpy(STARTUP_METASERVER,get_argument_str (IDENT_METASERVER));
+    {
+      LW_MACRO_STRCPY (STARTUP_METASERVER,
+		       get_argument_str (IDENT_METASERVER));
+    }
   else
-    strcpy(STARTUP_METASERVER,DEFAULT_METASERVER);   
+    {
+      LW_MACRO_STRCPY (STARTUP_METASERVER, DEFAULT_METASERVER);
+    }
 }
 
 /*------------------------------------------------------------------*/
-static void set_misc (void)
+static void
+set_misc (void)
 {
-  if (exist_argument(IDENT_CAPTURE))
+  if (exist_argument (IDENT_CAPTURE))
     {
-      STARTUP_CAPTURE=1;
+      STARTUP_CAPTURE = 1;
     }
-  if (exist_argument(IDENT_TOMBOLA))
+  if (exist_argument (IDENT_TOMBOLA))
     {
-      STARTUP_TOMBOLA=1;
+      STARTUP_TOMBOLA = 1;
     }
 }
 
 /*------------------------------------------------------------------*/
-static void set_various_hacks (void)
+static void
+set_various_hacks (void)
 {
 #ifndef ASM
   /*
@@ -385,25 +418,24 @@ static void set_various_hacks (void)
    * in, for we want the program to be able to tell others that it
    * can't do any assembly, in a network game for instance.
    */
-  STARTUP_ASM=0;
+  STARTUP_ASM = 0;
 #endif
 }
 
 /*------------------------------------------------------------------*/
-void set_startup (void)
+void
+set_startup (void)
 {
-  set_joystick();
-  set_load_states();
-  set_graphic_possibilities();
-  set_c_or_asm();
-  set_path();
-  set_stop();
-  set_safe();
-  set_auto_check();
-  set_bigdata_size();
-  set_metaserver();
-  set_misc();
-  set_various_hacks();
+  set_joystick ();
+  set_load_states ();
+  set_graphic_possibilities ();
+  set_c_or_asm ();
+  set_path ();
+  set_stop ();
+  set_safe ();
+  set_auto_check ();
+  set_bigdata_size ();
+  set_metaserver ();
+  set_misc ();
+  set_various_hacks ();
 }
-
-
