@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -66,8 +66,8 @@
 /* fonctions globales                                               */
 /*==================================================================*/
 
-void *archive_raw_texture (const char *filename);
-BITMAP *create_bg_texture (int num);
-BITMAP *create_fg_texture (int num);
+void *lw_texture_archive_raw (const char *filename);
+BITMAP *lw_texture_create_bg (int num);
+BITMAP *lw_texture_create_fg (int num);
 
 #endif
